/**
 * Functions for archive pages.
 */
(
	function( $ ) {
		'use strict';

		var Helpers = window.minimog.Helpers;

		$( document ).ready( function() {
			initArchiveLayoutSwitcher();
			initArchiveSidebarWidgetsCollapsible();
			handlerScrollInfinite();

			$( document.body ).on( 'MinimogGridLayoutColumnsChange', updateLayoutSwitcherState );

			$( document.body ).on( 'click', '.minimog-wp-widget-filter .filter-link', function( evt ) {
				evt.preventDefault();

				var $link = $( this ),
				    $item = $link.parent( 'li' ),
				    $list = $link.closest( 'ul' ),
				    href  = $link.attr( 'href' );

				if ( $list.hasClass( 'single-choice' ) ) {
					if ( $item.hasClass( 'chosen' ) ) {
						return;
					}

					$item.addClass( 'chosen' ).siblings().removeClass( 'chosen' );
				} else {
					$link.parent( 'li' ).toggleClass( 'chosen' );
				}

				filterProductsByUrl( href );
			} );

			$( document.body ).on( 'click', '.js-product-filter-link', function( evt ) {
				evt.preventDefault();

				var $link = $( this );

				if ( $link.hasClass( 'disabled' ) ) {
					return;
				}

				var href = $link.attr( 'href' );

				filterProductsByUrl( href );
			} );

			$( document.body ).on( 'click', '.woocommerce-pagination a.page-numbers', function( evt ) {
				evt.preventDefault();

				var $link = $( this );
				var href = $link.attr( 'href' );
				var url = window.location.origin + href;

				filterProductsByUrl( url );
			} );

			$( document.body ).on( 'click', '.shop-load-more-button', function( evt ) {
				evt.preventDefault();

				var $button = $( this );
				var href = $button.attr( 'data-url' );
				var url = window.location.origin + href;

				filterProductsByUrl( url, true );
			} );

			$( document.body ).on( 'change', '.js-product-ordering select.orderby', function( evt ) {
				var orderBy = $( this ).val();

				var href = Helpers.addUrlParam( window.location.href, 'orderby', orderBy );

				filterProductsByUrl( href );
			} );
		} );

		function updateLayoutSwitcherState( evt, $grid, oldColumns, newColumns ) {
			var $layoutSwitcher = $( '#archive-layout-switcher' );

			if ( 0 >= $layoutSwitcher.length ) {
				return;
			}

			var $currentItem = $layoutSwitcher.find( '.switcher-item[data-columns=' + newColumns + ']' );
			if ( $currentItem.length > 0 ) {
				$currentItem.siblings().removeClass( 'selected' );
				$currentItem.addClass( 'selected' );
			}
		}

		function filterProductsByUrl( url, loadMore = false ) {
			url = decodeURIComponent( url );
			/**
			 * We need send base url to render pagination links.
			 */
			const urlParts = new URL( url );
			var baseUrl = urlParts.pathname + urlParts.search;

			if ( ! loadMore ) {
				history.pushState( {}, null, url );
			}

			var data = Helpers.getUrlParamsAsObject( url );

			data.action = 'minimog_get_products';
			data.base_url = baseUrl;
			data.is_tax = $minimog.isTax;
			data.is_current_tax = $minimog.isCurrentTax;
			data.is_current_term_id = $minimog.isCurrentTermID;
			//data.is_current_tax = $minimog.isCurrentTax;

			var $queryVars = $( '#minimog-main-post-query' );
			if ( $queryVars.length > 0 ) {
				var queryVars = $queryVars.data( 'query' );
				data.posts_per_page = queryVars.posts_per_page;
			}

			var $filterWidgets = $( '.minimog-wp-widget-filter' );

			var showingWidgets = [];

			$filterWidgets.each( function() {
				var id = $( this ).attr( 'id' );
				var $widgetInstance = $( this ).find( '.widget-instance' );

				if ( $widgetInstance.length > 0 ) {
					var instance = $widgetInstance.data( 'instance' );
					var name = $widgetInstance.data( 'name' );

					showingWidgets.push( {
						'id': '#' + id,
						'name': name,
						'instance': instance
					} );
				}
			} );

			data.widgets = showingWidgets;

			var $btnLoadMore = $( '.shop-load-more-button' );

			$.ajax( {
				url: $minimog.ajaxurl,
				type: 'GET',
				data: data,
				dataType: 'json',
				cache: true,
				success: function( response ) {
					var $gridWrapper = $( '#minimog-main-post' );

					if ( ! loadMore ) {
						$gridWrapper.find( '.minimog-grid' ).empty();
					}

					var html = response.template;
					var $newItems = $( $.parseHTML( html ) );

					$gridWrapper.MinimogGridLayout( 'update', $newItems );

					if ( response.fragments ) {
						$.each( response.fragments, function( key, value ) {
							$( key ).empty();

							if ( '' !== value ) {
								/**
								 * Append only children.
								 * Avoid to use replaceWith to lost "key" events
								 */
								var $newElement = $( $.parseHTML( value ) );
								$( key ).html( $newElement.html() );
							}
						} );

						$( document.body ).trigger( 'minimog_get_product_fragments_loaded' );
					}
				},
				beforeSend: function() {
					if ( loadMore ) {
						Helpers.setElementHandling( $btnLoadMore );
					} else {
						Helpers.setBodyHandling();
					}
				},
				complete: function() {
					if ( loadMore ) {
						Helpers.unsetElementHandling( $btnLoadMore );
					} else {
						Helpers.setBodyCompleted();
					}
				}
			} );
		}

		function handlerScrollInfinite() {
			var $el = $( '.woocommerce-pagination' );

			if ( 'infinite' !== $el.data( 'type' ) ) {
				return;
			}

			var lastST = 0;
			var $window = $( window );

			$window.on( 'scroll', function() {
				var currentST = $( this ).scrollTop();

				// Scroll down only.
				if ( currentST > lastST ) {
					var windowHeight = $window.height();
					// 90% window height.
					var halfWH = 90 / 100 * windowHeight;
					halfWH = parseInt( halfWH );

					var elOffsetTop = $el.offset().top;
					var elHeight = $el.outerHeight( true );
					var offsetTop = elOffsetTop + elHeight;
					var finalOffset = offsetTop - halfWH;

					if ( currentST >= finalOffset ) {
						var $button = $el.find( '.shop-load-more-button' );

						if ( ! $button.hasClass( 'updating-icon' ) ) {
							$button.trigger( 'click' );
						}
					}
				}

				lastST = currentST;
			} );
		}

		function initArchiveLayoutSwitcher() {
			var $layoutSwitcher = $( '#archive-layout-switcher' );
			var $gridWrapper = $( '.minimog-main-post' );
			var SELECTED_CLASS = 'selected';

			$layoutSwitcher.on( 'click', '.switcher-item', function( evt ) {
				evt.preventDefault();

				var $item = $( this );

				if ( $item.hasClass( SELECTED_CLASS ) ) {
					return;
				}

				$item.siblings().removeClass( SELECTED_CLASS );
				$item.addClass( SELECTED_CLASS );

				var newLayout = $item.data( 'layout' );
				var newGridOptions = {};

				switch ( newLayout ) {
					case 'grid-one':
						newGridOptions.columns = 1;
						newGridOptions.disableColumnChange = true;
						$gridWrapper.addClass( 'style-list' );
						break;
					case 'grid-two':
						newGridOptions.columns = 2;
						newGridOptions.disableColumnChange = false;
						$gridWrapper.removeClass( 'style-list' );
						break;
					case 'grid-three':
						newGridOptions.columns = 3;
						newGridOptions.disableColumnChange = false;
						$gridWrapper.removeClass( 'style-list' );
						break;
					case 'grid-four':
						newGridOptions.columns = 4;
						newGridOptions.disableColumnChange = false;
						$gridWrapper.removeClass( 'style-list' );
						break;
					case 'grid-five':
						newGridOptions.columns = 5;
						newGridOptions.disableColumnChange = false;
						$gridWrapper.removeClass( 'style-list' );
						break;
				}

				$gridWrapper.MinimogGridLayout( 'updateLayout', newGridOptions );
			} );
		}

		function initArchiveSidebarWidgetsCollapsible() {
			var $sidebar = $( '.sidebar-widgets-collapsible' );

			if ( 0 >= $sidebar.length ) {
				return;
			}

			$sidebar.find( '.widget' ).each( function() {
				var $widget = $( this );
				var duration = 250;
				var ACTIVE_CLASS = 'collapsed';

				// Wrap content with new div.
				$widget.children().not( '.widget-title, .widget-instance, .widget-content' ).wrapAll( '<div class="widget-content"></div>' );

				$widget.on( 'click', '.widget-title', function( evt ) {
					if ( $widget.hasClass( ACTIVE_CLASS ) ) {
						$widget.removeClass( ACTIVE_CLASS );
						$widget.children( '.widget-content' ).stop().slideDown( duration );
					} else {
						$widget.addClass( ACTIVE_CLASS );
						$widget.children( '.widget-content' ).stop().slideUp( duration );
					}
				} );
			} );
		}

	}( jQuery )
);
