(
	function( $ ) {
		'use strict';

		var Helpers = window.minimog.Helpers;

		$( document ).ready( function() {
			var messages = $minimogLogin.validatorMessages;

			jQuery.extend( jQuery.validator.messages, {
				required: messages.required,
				remote: messages.remote,
				email: messages.email,
				url: messages.url,
				date: messages.date,
				dateISO: messages.dateISO,
				number: messages.number,
				digits: messages.digits,
				creditcard: messages.creditcard,
				equalTo: messages.equalTo,
				accept: messages.accept,
				maxlength: jQuery.validator.format( messages.maxlength ),
				minlength: jQuery.validator.format( messages.minlength ),
				rangelength: jQuery.validator.format( messages.rangelength ),
				range: jQuery.validator.format( messages.range ),
				max: jQuery.validator.format( messages.max ),
				min: jQuery.validator.format( messages.min )
			} );

			var $body = $( 'body' );
			var $modalLogin = $( '#modal-user-login' );
			var $modalRegister = $( '#modal-user-register' );
			var $modalLostPassword = $( '#modal-user-lost-password' );

			// Remove inline css.
			$modalLogin.find( '.mo-openid-app-icons .mo_btn-social' ).removeAttr( 'style' );
			$modalLogin.find( '.mo-openid-app-icons .mo_btn-social .mofa' ).removeAttr( 'style' );
			$modalLogin.find( '.mo-openid-app-icons .mo_btn-social svg' ).removeAttr( 'style' );

			var $loginForm = $modalLogin.find( '#minimog-login-form' );
			$loginForm.validate( {
				rules: {
					user_login: {
						required: true
					},
					password: {
						required: true,
					}
				},
				submitHandler: function( form ) {
					var $form = $( form );
					var $submitBtn = $form.find( 'button[type="submit"]' );

					$.ajax( {
						url: $minimog.ajaxurl,
						type: 'POST',
						cache: false,
						dataType: 'json',
						data: $form.serialize(),
						success: function( response ) {
							if ( ! response.success ) {
								$form.find( '.form-response-messages' ).html( response.data.messages ).addClass( 'error' ).show();
							} else {
								$form.find( '.form-response-messages' ).html( response.data.messages ).addClass( 'success' ).show();

								if ( '' !== response.data.redirect_url ) {
									window.location.href = response.data.redirect_url;
								} else {
									location.reload();
								}
							}
						},
						beforeSend: function() {
							$form.find( '.form-response-messages' ).html( '' ).removeClass( 'error success' ).hide();
							Helpers.setElementHandling( $submitBtn );
						},
						complete: function() {
							Helpers.unsetElementHandling( $submitBtn );
						}
					} );
				}
			} );

			if ( $body.hasClass( 'required-login' ) && ! $body.hasClass( 'logged-in' ) ) {
				$modalLogin.MinimogModal( 'open' );
			}

			$body.on( 'click', '.open-modal-login', function( e ) {
				e.preventDefault();
				e.stopPropagation();

				$modalLogin.MinimogModal( 'open' );
			} );

			$body.on( 'click', '.open-modal-register', function( e ) {
				e.preventDefault();
				e.stopPropagation();


				$modalRegister.MinimogModal( 'open' );
			} );

			$body.on( 'click', '.open-modal-lost-password', function( e ) {
				e.preventDefault();
				e.stopPropagation();

				$modalLostPassword.MinimogModal( 'open' );
			} );

			$body.on( 'click', '.btn-pw-toggle', function( e ) {
				e.preventDefault();
				e.stopPropagation();

				var groupField = $( this ).parent( '.form-input-password' );
				var pwField = groupField.children( 'input' );

				if ( 'password' === pwField.attr( 'type' ) ) {
					pwField.attr( 'type', 'text' );
					groupField.addClass( 'show-pw' );
				} else {
					pwField.attr( 'type', 'password' );
					groupField.removeClass( 'show-pw' );
				}
			} );

			var $registerForm = $modalRegister.find( '#minimog-register-form' );
			$registerForm.validate( {
				rules: {
					fullname: {
						required: true,
					},
					username: {
						required: true,
						minlength: 4,
					},
					email: {
						required: true,
						email: true
					},
					password: {
						required: true,
						minlength: 8,
						maxlength: 30
					},
				},
				submitHandler: function( form ) {
					var $form = $( form );
					var $submitBtn = $form.find( 'button[type="submit"]' );

					$.ajax( {
						url: $minimog.ajaxurl,
						type: 'POST',
						cache: false,
						dataType: 'json',
						data: $form.serialize(),
						success: function( response ) {
							if ( ! response.success ) {
								$form.find( '.form-response-messages' ).html( response.data.messages ).addClass( 'error' ).show();
							} else {
								$form.find( '.form-response-messages' ).html( response.data.messages ).addClass( 'success' ).show();
								location.reload();
							}
						},
						beforeSend: function() {
							$form.find( '.form-response-messages' ).html( '' ).removeClass( 'error success' ).hide();
							Helpers.setElementHandling( $submitBtn );
						},
						complete: function() {
							Helpers.unsetElementHandling( $submitBtn );
						}
					} );
				}
			} );

			var $lostPasswordForm = $modalLostPassword.find( '#minimog-lost-password-form' );
			$lostPasswordForm.on( 'submit', function( e ) {
				e.preventDefault();

				var $form = $( this );
				var $submitBtn = $form.find( 'button[type="submit"]' );

				$.ajax( {
					type: 'post',
					url: $minimog.ajaxurl,
					dataType: 'json',
					data: $form.serialize(),
					success: function( response ) {
						if ( ! response.success ) {
							$form.find( '.form-response-messages' ).html( response.data.messages ).addClass( 'error' ).show();
						} else {
							$form.find( '.form-response-messages' ).html( response.data.messages ).addClass( 'success' ).show();
						}
					},
					beforeSend: function() {
						$form.find( '.form-response-messages' ).html( '' ).removeClass( 'error success' ).hide();
						Helpers.setElementHandling( $submitBtn );
					},
					complete: function() {
						Helpers.unsetElementHandling( $submitBtn );
					}
				} );
			} );
		} );

	}( jQuery )
);
