(
	function( $ ) {
		'use strict';

		var Helpers = window.minimog.Helpers;

		var $cartTable = $( '#cart-table-wrap' );

		$( document ).ready( function() {
			initCart();
		} );

		$( document.body ).on( 'wc_fragments_refreshed', function() {
			Helpers.setBodyCompleted();
		} );

		$( '#modal-cart-order-notes' ).on( 'submit', 'form', save_order_notes );

		// Shipping calculate.
		$( document ).on( 'change', 'select.shipping_method, :input[name^=shipping_method]', shipping_method_selected );

		$( document ).on( 'submit', 'form.fly-cart-shipping-calculator', shipping_calculator_submit );

		$( document ).on( 'click', '.btn-remove-from-cart', remove_from_cart );

		function initCart() {
			var timeout;
			$cartTable.on( 'change', '.qty', function() {
				var $qty = $( this );

				if ( timeout !== undefined ) {
					clearTimeout( timeout );
				}

				timeout = setTimeout( function() {
					var itemKey = $qty.attr( 'name' );
					var itemQty = $qty.val();

					update_quantity( itemKey, itemQty );
				}, 500 );
			} );
		}

		function remove_from_cart( evt ) {
			evt.preventDefault();

			var $thisButton = $( this );

			$.ajax( {
				type: 'POST',
				url: $minimogWoo.wc_ajax_url.toString().replace( '%%endpoint%%', 'remove_from_cart' ),
				data: {
					cart_item_key: $thisButton.data( 'cart_item_key' )
				},
				dataType: 'json',
				beforeSend: function() {
					Helpers.setBodyHandling();
				},
				success: function( response ) {
					if ( ! response || ! response.fragments ) {
						window.location = $thisButton.attr( 'href' );
						return;
					}

					$( document.body ).trigger( 'removed_from_cart', [
						response.fragments,
						response.cart_hash,
						$thisButton
					] );

					Helpers.setBodyCompleted();
					handle_lazy_images();
				},
				error: function() {
					window.location = $thisButton.attr( 'href' );
					return;
				}
			} );
		}

		function save_order_notes() {
			var $form = $( this );
			var $submitButton = $form.find( 'button[type=submit]' );

			var notes = $( this ).find( 'textarea[name="order_comments"]' ).val();

			var data = {
				action: 'minimog_save_order_notes',
				order_notes: notes,
			};

			$.ajax( {
				type: 'POST',
				url: $minimog.ajaxurl,
				data: data,
				dataType: 'json',
				success: function( response ) {
					if ( response.data && response.data.fragments ) {
						$.each( response.data.fragments, function( key, value ) {
							$( key ).replaceWith( value );
						} );
					}

					// Sync notes on other places.
					$( 'textarea[name="order_comments"]' ).val( notes );
				},
				beforeSend: function() {
					Helpers.setElementHandling( $submitButton );
				},
				complete: function() {
					Helpers.unsetElementHandling( $submitButton );
					$form.closest( '.minimog-modal' ).MinimogModal( 'close' );
				}
			} );

			return false;
		}

		function update_quantity( cart_item_key, cart_item_qty ) {
			var data = {
				action: 'minimog_update_product_quantity',
				cart_item_key: cart_item_key,
				cart_item_qty: cart_item_qty,
				security: $minimog.nonce,
			};

			$.ajax( {
				url: $minimog.ajaxurl,
				type: 'POST',
				cache: false,
				dataType: 'json',
				data: data,
				beforeSend: function() {
					Helpers.setBodyHandling();
				},
				error: function() {
					Helpers.setBodyCompleted();
				},
				success: function( response ) {
					$( document.body ).trigger( 'minimog_update_qty', [ cart_item_key, cart_item_qty ] );

					$( document.body ).trigger( 'wc_fragment_refresh' );
				},
			} );
		}

		/**
		 * Clone from wc-cart
		 * Handles when a shipping method is selected.
		 */
		function shipping_method_selected() {
			var shipping_methods = {};

			// eslint-disable-next-line max-len
			$( 'select.shipping_method, :input[name^=shipping_method][type=radio]:checked, :input[name^=shipping_method][type=hidden]' ).each( function() {
				shipping_methods[ $( this ).data( 'index' ) ] = $( this ).val();
			} );

			block( $( 'div.cart_totals' ) );

			var data = {
				security: wc_cart_params.update_shipping_method_nonce,
				shipping_method: shipping_methods
			};

			$.ajax( {
				type: 'post',
				url: get_url( 'update_shipping_method' ),
				data: data,
				dataType: 'html',
				success: function( response ) {
					update_cart_totals_div( response );
				},
				complete: function() {
					unblock( $( 'div.cart_totals' ) );
					$( document.body ).trigger( 'updated_shipping_method' );
				}
			} );
		}

		/**
		 * Clone from wc-cart
		 * Handles a shipping calculator form submit.
		 *
		 * @param {Object} evt The JQuery event.
		 */
		function shipping_calculator_submit( evt ) {
			evt.preventDefault();

			var $form = $( evt.currentTarget );

			$( '<input />' ).attr( 'type', 'hidden' )
			                .attr( 'name', 'action' )
			                .attr( 'value', 'minimog_calculate_shipping' )
			                .appendTo( $form );

			$.ajax( {
				type: $form.attr( 'method' ),
				url: $minimog.ajaxurl,
				data: $form.serialize(),
				dataType: 'json',
				success: function( response ) {
					if ( response.data.fragments ) {
						$.each( response.data.fragments, function( key, value ) {
							$( key ).empty();

							if ( '' !== value ) {
								/**
								 * Append only children.
								 * Avoid to use replaceWith to lost "key" events
								 */
								var $newElement = $( $.parseHTML( value ) );
								$( key ).html( $newElement.html() );
							}
						} );
					}
				},
				beforeSend: function() {
					$form.closest( '.minimog-modal' ).MinimogModal( 'close' );
					Helpers.setBodyHandling();
				},
				complete: function() {
					Helpers.setBodyCompleted();
				}
			} );
		}

		function handle_lazy_images() {
			if ( $.fn.laziestloader ) {
				var llImages = $cartTable.find( '.ll-image' );

				if ( llImages.length > 0 ) {
					llImages.laziestloader( {}, function() {
						$( this ).unwrap( '.minimog-lazy-image' );
					} ).trigger( 'laziestloader' );
				}
			}
		}
	}( jQuery )
);
