(
	function( $ ) {
		'use strict';

		var $window = $( window );
		var $body = $( 'body' );

		var Helpers = window.minimog.Helpers;

		$( document ).ready( function() {
			initQuickViewPopup();
			addProductVariationToCart();
			singleProductAddToCart();
			loopProductVariationSelection();
			widgetProductCategories();
			initShopOffSidebar();
			$( 'body' ).on( 'isw_selected', swatchesSelected );
			combinedVariationsDropdownTrigger();
			wooAdvancedDiscounts();

			reAddWCFunctions();
		} );

		/**
		 * Support Product Bundle + Frequently Bought Together.
		 */
		function combinedVariationsDropdownTrigger() {
			$( document.body ).on( 'change', '.product-variation-select', function() {
				var $form = $( this ).parents( '.minimog-variation-select-wrap' ).find( '.variations_form' );
				var val = $( this ).val();

				if ( '' !== val ) {
					var attributes = JSON.parse( val );

					for ( const key in attributes ) {
						$form.find( 'select[name="' + key + '"]' ).val( attributes[ key ] ).trigger( 'change' );
					}
				} else {
					$form.find( '.reset_variations' ).trigger( 'click' );
				}
			} );
		}

		function swatchesSelected( evt, attr, term, title, $thisTerm ) {
			var $termRow = $thisTerm.parents( '.row-isw-swatch' ).first();

			if ( $termRow.hasClass( 'row-isw-swatch--isw_color' ) || $termRow.hasClass( 'row-isw-swatch--isw_image' ) ) {
				$termRow.find( '.selected-term-name' ).html( title );
			}
		}

		function initShopOffSidebar() {
			var $pageSidebar = $( '.page-sidebar' );

			$( document ).on( 'click', '.btn-js-open-off-sidebar', function( evt ) {
				evt.preventDefault();
				var $toggleBtn = $( this );

				var sidebar = $toggleBtn.data( 'sidebar-target' );
				var $theSidebar = $pageSidebar.filter( '.sidebar-' + sidebar );

				if ( $theSidebar.length > 0 ) {
					$body.addClass( 'off-sidebar-opened' );
					Helpers.setBodyOverflow();

					var $sidebarContent = $theSidebar.find( '.page-sidebar-content-wrap' );
					$sidebarContent.outerHeight( window.innerHeight );

					if ( $.fn.perfectScrollbar && ! Helpers.isHandheld() ) {
						$sidebarContent.perfectScrollbar( {
							suppressScrollX: true
						} );
					}
				}
			} );

			$( document ).on( 'click', '.btn-close-off-sidebar', function( evt ) {
				evt.preventDefault();

				$body.removeClass( 'off-sidebar-opened' );
				Helpers.unsetBodyOverflow();
			} );

			$pageSidebar.on( 'click', function( e ) {
				if ( e.target !== this ) {
					return;
				}

				$body.removeClass( 'off-sidebar-opened' );
				Helpers.unsetBodyOverflow();
			} );

			var breakpoint = 991;
			var mobileToggle = $body.hasClass( 'page-sidebar-off-mobile' ) ? true : false;

			if ( mobileToggle ) {
				var prevWW = window.innerWidth;
				toggleOffSidebar();

				$window.on( 'resize', function() {
					var isToggle = true;
					if ( prevWW !== window.innerWidth ) { // Horizontal resize only.
						if (
							(
								prevWW <= breakpoint && window.innerWidth <= breakpoint
							)
							|| (
								prevWW > breakpoint && window.innerWidth > breakpoint
							)
						) {
							isToggle = false;
						}

						if ( isToggle ) {
							toggleOffSidebar();
						}
					}

					prevWW = window.innerWidth;
				} );
			}

			function toggleOffSidebar() {
				if ( window.innerWidth <= breakpoint ) {
					$pageSidebar.addClass( 'sidebar-switching sidebar-off' );
				} else {
					$pageSidebar.addClass( 'sidebar-switching' ).removeClass( 'sidebar-off' );
				}

				setTimeout( function() {
					$pageSidebar.removeClass( 'sidebar-switching' );
				}, 350 );
			}
		}

		function initQuickViewPopup() {
			$( '.minimog-product' ).on( 'click', '.quick-view-btn', function( e ) {
				e.preventDefault();
				e.stopPropagation();

				var $button = $( this );

				// Avoid multi clicks.
				if ( $button.hasClass( 'loading' ) ) {
					return;
				}

				if ( ! $.fn.MinimogModal ) {
					return;
				}

				$button.addClass( 'loading' );
				var productID = $button.data( 'pid' );

				/**
				 * Avoid duplicate ajax request.
				 */
				var $popup = $body.children( '#' + 'modal-quick-view-product-' + productID );
				if ( $popup.length > 0 ) {
					openQuickViewPopup( $popup, $button );
				} else {
					var data = {
						action: 'product_quick_view',
						pid: productID
					};

					$.ajax( {
						url: $minimog.ajaxurl,
						type: 'GET',
						data: $.param( data ),
						dataType: 'json',
						cache: true,
						success: function( results ) {
							$popup = $( results.template );
							$body.append( $popup );
							openQuickViewPopup( $popup, $button );
						},
					} );
				}
			} );
		}

		function openQuickViewPopup( $popup, $button ) {
			var $contentWrap = $popup.find( '.product-container' );
			var $productWrap = $contentWrap.find( '.woo-single-info' );
			var $productImages = $contentWrap.find( '.woo-single-images' );

			var settings = $contentWrap.data( 'quick-view' );

			var contentPadding = settings.spacing * 2;

			var $sliderWrap = $productImages.children( '.woo-single-gallery' );
			var sliderOptions = {};
			if ( $sliderWrap.hasClass( 'has-thumbs-slider' ) ) {
				var thumbsSlider = $sliderWrap.children( '.minimog-thumbs-swiper' ).MinimogSwiper();
				sliderOptions = {
					thumbs: {
						swiper: thumbsSlider
					}
				};
			}
			var $mainSlider = $sliderWrap.children( '.minimog-main-swiper' );
			var mainSlider = null;
			if ( $mainSlider.length > 0 ) {
				mainSlider = $mainSlider.MinimogSwiper( sliderOptions );
			}

			var productImageHeight = $productImages.height();
			var popupHeight        = productImageHeight,
			    popupContentHeight = productImageHeight;
			// Max height of popup = Window height - top bottom spacing.
			var maxHeight = window.innerHeight - 60;

			var $scrollable = $productWrap;

			if ( settings.imageCover ) {
				$scrollable = $contentWrap.find( '.quick-view-col-summary .inner-content' );
				popupHeight = productImageHeight + contentPadding;
				popupContentHeight = Math.min( maxHeight, popupHeight );

				if ( settings.spacing > 0 ) {
					popupContentHeight -= contentPadding;
				} else {
					popupContentHeight -= 60;
				}
			} else {
				popupHeight = productImageHeight + contentPadding;
				popupContentHeight = Math.min( maxHeight, popupHeight );
				popupContentHeight -= contentPadding;
			}

			$scrollable.outerHeight( parseInt( popupContentHeight ) );

			if ( $.fn.perfectScrollbar && ! Helpers.isHandheld() ) {
				$scrollable.perfectScrollbar( {
					suppressScrollX: true
				} );
			}

			if ( settings.imageCover ) {
				$contentWrap.find( '.woo-single-images' ).addClass( 'image-cover' );
			}

			var $variationsForm = $popup.find( '.cart.variations_form' );

			// Re init add to cart form variation.
			if ( $variationsForm.length > 0 && typeof wc_add_to_cart_variation_params !== 'undefined' ) {
				$variationsForm.wc_variation_form();

				if ( typeof isw != 'undefined' && typeof isw.Swatches !== 'undefined' ) {
					isw.Swatches.register( $variationsForm );
				}
			}

			var $form = $popup.find( '.variations_form' );
			var variations = $form.data( 'product_variations' );

			// Re init Quantity select.
			var $renderTarget = $form.find( '.row-isw-swatch-quantity-wrap' );

			$form.find( 'select[name="quantity"]' ).MinimogNiceSelect( {
				renderTarget: $renderTarget
			} );

			$form.on( 'found_variation', function( event, variation ) {
				var $stock = $form.find( '.product-stock-availability' );

				if ( variation.availability_html ) {
					Helpers.wooSetContentHTML( $stock, variation.availability_html );
				} else {
					Helpers.wooResetContentHTML( $stock );
				}
			} );

			$form.on( 'reset_data', function( event ) {
				var $stock = $form.find( '.product-stock-availability' );
				Helpers.wooResetContentHTML( $stock );
			} );

			if ( mainSlider ) {
				$form.find( 'select' ).on( 'change', function() {
					var isFieldSelected = true;
					var needReset = false;
					var globalAttrs = {};

					var formValues = $form.serializeArray();

					// Check all attributes selected.
					for ( var i = 0; i < formValues.length; i ++ ) {

						var _name = formValues[ i ].name;

						if ( _name.substring( 0, 10 ) === 'attribute_' ) {

							globalAttrs[ _name ] = formValues[ i ].value;

							if ( formValues[ i ].value === '' ) {
								isFieldSelected = false;

								break;
							}
						}
					}

					if ( isFieldSelected === true ) {
						// Convert to array.
						var selectedAttributes = Object.entries( globalAttrs );

						var variationImageID = 0;
						var minMatch = 0;

						for ( var i = variations.length - 1; i >= 0; i -- ) {
							var currentVariation = variations[ i ];
							var currentAttributes = Object.entries( currentVariation.attributes ); // Convert to array.
							var loopMatch = 0;

							// Compare selected variation with all variations to find best matches.
							currentAttributes.forEach( ( [ key, value ] ) => {
								selectedAttributes.forEach( ( [ selectedKey, selectedValue ] ) => {

									if ( selectedKey === key ) {
										if ( selectedValue === value
										     || '' === value // Any Terms.
										) {
											loopMatch ++;
										}
									}
								} );
							} );

							if ( minMatch < loopMatch ) {
								minMatch = loopMatch;
								variationImageID = currentVariation.image_id;
							}
						}

						if ( variationImageID ) {
							mainSlider.$wrapperEl.find( '.swiper-slide' ).each( function( index ) {
								var slideImageID = $( this ).attr( 'data-image-id' );
								slideImageID = parseInt( slideImageID );

								if ( slideImageID === variationImageID ) {
									mainSlider.slideTo( index );

									return false;
								}
							} );
						} else {
							needReset = true;
						}
					} else {
						needReset = true;
					}

					// Reset to main image.
					if ( needReset ) {
						var $mainImage = mainSlider.$wrapperEl.find( '.product-main-image' );
						var index = $mainImage.index();
						mainSlider.slideTo( index );
					}
				} );
			}

			$popup.MinimogModal( {
				perfectScrollbar: false
			} ).MinimogModal( 'open' );
			$button.removeClass( 'loading' );
		}

		function singleProductAddToCart() {
			// wc_add_to_cart_params is required to continue, ensure the object exists.
			if ( typeof wc_add_to_cart_params === 'undefined' ) {
				return false;
			}

			/**
			 * Ajax add to cart.
			 * button query selector to compatible with Lumise add on.
			 */
			$( document ).on( 'click', 'button.single_add_to_cart_button', function( evt ) {
				var $thisButton = $( this );

				// Do nothing if this is external product.
				if ( ! $thisButton.hasClass( 'external-add-to-cart-button' ) ) {
					evt.preventDefault();

					if ( $thisButton.hasClass( 'disabled' ) ) { // Variation select required.
						return false;
					}

					if ( $thisButton.hasClass( 'woosb-disabled' ) ) { // Smart Bundle select required.
						return false;
					}

					var $variationsForm = $thisButton.closest( 'form.cart' ),
					    productID       = $variationsForm.find( '[name=add-to-cart]' ).val(),
					    variationID     = $variationsForm.find( 'input[name=variation_id]' ).val(),
					    quantity        = $variationsForm.find( '.quantity .qty[name=quantity]' ).val();

					if ( 'add-to-cart' === $thisButton.attr( 'name' ) ) {
						productID = $thisButton.val();
					}

					if ( 0 === productID ) {
						return;
					}

					var data = {
						action: 'minimog_woocommerce_add_to_cart',
						product_id: productID,
						variation_id: variationID,
					};

					$variationsForm.serializeArray().map( function( attr ) {
						if ( attr.name !== 'add-to-cart' ) {
							if ( attr.name.endsWith( '[]' ) ) {
								let name = attr.name.substring( 0, attr.name.length - 2 );
								if ( ! (
									name in data
								) ) {
									data[ name ] = [];
								}
								data[ name ].push( attr.value );
							} else {
								data[ attr.name ] = attr.value;
							}
						}
					} );

					// Custom quantity per button.
					if ( $thisButton.attr( 'data-qty' ) ) {
						quantity = parseInt( $thisButton.attr( 'data-qty' ) );
					}
					data.quantity = quantity;

					$thisButton.removeClass( 'added' ).addClass( 'loading updating-icon' );

					// Trigger event.
					$( 'body' ).trigger( 'adding_to_cart', [ $thisButton, data ] );

					// Ajax action.
					$.post( wc_add_to_cart_params.ajax_url, data, function( response ) {

						if ( ! response ) {
							return;
						}

						if ( response.error && response.product_url ) {
							window.location = response.product_url;
							return;
						}

						// Redirect to cart option.
						if ( wc_add_to_cart_params.cart_redirect_after_add === 'yes' ) {
							window.location = wc_add_to_cart_params.cart_url;
							return;
						}

						// Trigger event so themes can refresh other areas.
						$( document.body ).trigger( 'added_to_cart', [
							response.fragments,
							response.cart_hash,
							$thisButton
						] );

					} ).always( function() {
						$thisButton.addClass( 'added' ).removeClass( 'loading updating-icon' );
					} );

					return false;
				}
			} );
		}

		function addProductVariationToCart() {
			// wc_add_to_cart_params is required to continue, ensure the object exists.
			if ( typeof wc_add_to_cart_params === 'undefined' ) {
				return false;
			}

			// Ajax add product variation to cart
			$( document ).on( 'click', '.ajax_add_variation_to_cart', function( e ) {
				e.preventDefault();
				e.stopPropagation();

				var $thisbutton  = $( this ),
				    quantity     = $thisbutton.data( 'quantity' ),
				    variation_id = 0,
				    data         = {};

				var $variationSelect = $thisbutton.siblings( 'select[name="product_variation_id"]' );

				if ( $variationSelect.length > 0 ) { // Combined attributes dropdown.
					var $variationSelectedOption = $variationSelect.children( ':selected' );
					variation_id = $variationSelectedOption.data( 'variation-id' );
					data = $variationSelectedOption.val();
					data = JSON.parse( data );
				} else {
					var $variationsForm = $thisbutton.parents( '.product' ).first().find( '.variations_form' );

					if ( $variationsForm.length > 0 ) {
						var check = true;

						var variations = $variationsForm.find( 'select[name^=attribute]' );

						variations.each( function() {
							var $this          = $( this ),
							    attributeName  = $this.attr( 'name' ),
							    attributeValue = $this.val();

							if ( attributeValue.length === 0 ) {
								check = false;
							} else {
								data[ attributeName ] = attributeValue;
							}
						} );

						if ( ! check ) {
							window.alert( 'Please select a product option before adding this product to your cart.' );

							return false;
						}

						variation_id = $variationsForm.find( '.variation_id' ).val();
					}
				}

				if ( ! variation_id || ! data ) {
					window.alert( 'Please select a product option before adding this product to your cart.' );

					return false;
				}

				$thisbutton.removeClass( 'added' ).addClass( 'loading updating-icon' );

				data.action = 'minimog_woocommerce_add_to_cart';
				data.quantity = quantity;
				data.product_id = variation_id;

				// Trigger event
				$( 'body' ).trigger( 'adding_to_cart', [ $thisbutton, data ] );

				// Ajax action
				$.post( wc_add_to_cart_params.ajax_url, data, function( response ) {

					if ( ! response ) {
						return;
					}

					if ( response.error && response.product_url ) {
						window.location = response.product_url;
						return;
					}

					// Redirect to cart option
					if ( wc_add_to_cart_params.cart_redirect_after_add === 'yes' ) {
						window.location = wc_add_to_cart_params.cart_url;
						return;
					}

					// Trigger event so themes can refresh other areas.
					$( document.body ).trigger( 'added_to_cart', [
						response.fragments,
						response.cart_hash,
						$thisbutton
					] );

				} ).always( function() {
					$thisbutton.addClass( 'added' ).removeClass( 'loading updating-icon' );
				} );

				return false;
			} );
		}

		function loopProductVariationSelection() {
			$( document.body ).on( 'click', '.term-link', function() {
				var $currentTerm = $( this );
				var $form = $( this ).parents( '.loop-product-variation-selector' ).first();

				if ( 0 >= $form.length ) {
					return;
				}

				if ( $currentTerm.hasClass( 'selected' ) ) {
					return;
				}

				var $product = $form.closest( '.product' );
				var productAttribute = $form.data( 'product_attribute' );
				var variations = $form.data( 'product_variations' );
				var $variationsImages = $form.data( 'product_variations_images' );
				var foundVariation = false;

				$currentTerm.siblings().removeClass( 'selected' );
				$currentTerm.addClass( 'selected' );

				var selectedTerm = $currentTerm.data( 'term' );

				var $selectBox = $product.find( 'select[name=' + productAttribute + ']' );
				if ( $selectBox.length > 0 ) {
					$selectBox.val( selectedTerm ).trigger( 'change' );
				}

				for ( var i = variations.length - 1; i >= 0; i -- ) {
					var currentVariation = variations[ i ];

					if ( currentVariation.attributes ) {
						var currentAttributes = Object.entries( currentVariation.attributes ); // Convert to array.

						// Compare selected variation with all variations to find best matches.
						currentAttributes.forEach( ( [ key, value ] ) => {
							if ( productAttribute === key && value === selectedTerm ) {
								foundVariation = currentVariation;
							}
						} );
					}
				}

				if ( false !== foundVariation ) {
					var image_url = $variationsImages[ foundVariation[ 'variation_id' ] ];
					$product.find( '.product-main-image img' ).attr( 'src', image_url );

					var variationPriceHtml = foundVariation[ 'price_html' ];
					if ( '' !== variationPriceHtml ) { // Do nothing if all variations same price.
						$product.find( '.price' ).replaceWith( variationPriceHtml );
					}
				}
			} );

			$( '.loop-product-variation-selector' ).each( function() {
				$( this ).find( '.term-link' ).first().trigger( 'click' );
			} );
		}

		function widgetProductCategories() {
			$( '.widget_product_categories' ).each( function() {
				var $menu = $( this );
				var ACTIVE_CLASS = 'opened';
				var animationDuration = 250;

				$menu.find( '.cat-parent' ).each( function() {
					var $currentItem = $( this );
					var $newLink = $( this ).children( 'a' ).clone();
					var newLinkHtml = 'All ' + $newLink.html();
					$newLink.html( newLinkHtml );

					var $newItem = $( '<li class="cat-item cat-item-all"></li>' );

					if ( $currentItem.hasClass( 'current-cat' ) ) {
						$currentItem.removeClass( 'current-cat' );
						$currentItem.addClass( 'current-cat-parent' );

						$newItem.addClass( 'current-cat' );
					}

					$newItem.append( $newLink );
					$( this ).children( '.children' ).prepend( $newItem );
				} );

				$menu.on( 'click', 'a', function( evt ) {
					var $itemLink = $( this );
					var $item = $itemLink.parent( 'li' );

					var $children = $itemLink.siblings( '.children' );

					if ( $children.length > 0 ) {
						evt.preventDefault();
						evt.stopPropagation();

						if ( $item.hasClass( ACTIVE_CLASS ) ) {
							$item.removeClass( ACTIVE_CLASS );
							$item.find( '.' + ACTIVE_CLASS ).removeClass( ACTIVE_CLASS ); // Close all children.
							$children.stop().slideUp( animationDuration );
						} else {
							$item.siblings( '.' + ACTIVE_CLASS ).removeClass( ACTIVE_CLASS ).children( '.children' ).stop().slideUp( animationDuration ); // Close other items.
							$item.addClass( ACTIVE_CLASS );
							$children.stop().slideDown( animationDuration );
						}
					}
				} );

				var $currentCats = $menu.find( '.current-cat-parent, .current-cat' );
				$currentCats.addClass( ACTIVE_CLASS );
				$currentCats.children( '.children' ).stop().slideDown( animationDuration );
			} );
		}

		/**
		 * Rewrite Woo Advanced Discounts plugin
		 */
		function wooAdvancedDiscounts() {
			$( 'body' ).on( 'change', 'input[name="payment_method"], #billing_country, #shipping_country, #shipping_state, #billing_state', function() {
				setTimeout( function() {
					$( 'body' ).trigger( 'update_checkout' );
				}, 2000 );
			} );

			// Fix event for quick view.
			$( document.body ).on( 'show_variation', '.variations_form', function( evt, variation ) {
				var $form = $( this );

				var variation_id = $form.find( 'input[name="variation_id"]' ).val();
				if ( variation_id ) {
					$form.find( '.wad-qty-pricing-table' ).hide();
					$form.find( '.wad-qty-pricing-table[data-id="' + variation_id + '"]' ).show();
				}
			} );
		}

		/**
		 * We dequeue woocommerce.js plugin script
		 * So we need add some needed functions back.
		 * Commented code unused.
		 */
		function reAddWCFunctions() {
			/*$( '.woocommerce-ordering' ).on( 'change', 'select.orderby', function() {
				$( this ).closest( 'form' ).trigger( 'submit' );
			} );

			// Target quantity inputs on product pages.
			$( 'input.qty:not(.product-quantity input.qty)' ).each( function() {
				var min = parseFloat( $( this ).attr( 'min' ) );

				if ( min >= 0 && parseFloat( $( this ).val() ) < min ) {
					$( this ).val( min );
				}
			} );*/

			var noticeID   = $( '.woocommerce-store-notice' ).data( 'noticeId' ) || '',
			    cookieName = 'store_notice' + noticeID;

			// Check the value of that cookie and show/hide the notice accordingly
			if ( 'hidden' === Cookies.get( cookieName ) ) {
				$( '.woocommerce-store-notice' ).hide();
			} else {
				$( '.woocommerce-store-notice' ).show();
			}

			// Set a cookie and hide the store notice when the dismiss button is clicked
			$( '.woocommerce-store-notice__dismiss-link' ).on( 'click', function( event ) {
				Cookies.set( cookieName, 'hidden', { path: '/' } );
				$( '.woocommerce-store-notice' ).hide();
				event.preventDefault();
			} );

			// Make form field descriptions toggle on focus.
			if ( $( '.woocommerce-input-wrapper span.description' ).length ) {
				$( document.body ).on( 'click', function() {
					$( '.woocommerce-input-wrapper span.description:visible' ).prop( 'aria-hidden', true ).slideUp( 250 );
				} );
			}

			$( '.woocommerce-input-wrapper' ).on( 'click', function( event ) {
				event.stopPropagation();
			} );

			$( '.woocommerce-input-wrapper :input' ).on( 'keydown', function( event ) {
				var input       = $( this ),
				    parent      = input.parent(),
				    description = parent.find( 'span.description' );

				if ( 27 === event.which && description.length && description.is( ':visible' ) ) {
					description.prop( 'aria-hidden', true ).slideUp( 250 );
					event.preventDefault();
					return false;
				}
			} ).on( 'click focus', function() {
				var input       = $( this ),
				    parent      = input.parent(),
				    description = parent.find( 'span.description' );

				parent.addClass( 'currentTarget' );

				$( '.woocommerce-input-wrapper:not(.currentTarget) span.description:visible' ).prop( 'aria-hidden', true ).slideUp( 250 );

				if ( description.length && description.is( ':hidden' ) ) {
					description.prop( 'aria-hidden', false ).slideDown( 250 );
				}

				parent.removeClass( 'currentTarget' );
			} );

			/*
			// Common scroll to element code.
			$.scroll_to_notices = function( scrollElement ) {
				if ( scrollElement.length ) {
					$( 'html, body' ).animate( {
						scrollTop: (
							scrollElement.offset().top - 100
						)
					}, 1000 );
				}
			};

			// Show password visibility hover icon on woocommerce forms.
			$( '.woocommerce form .woocommerce-Input[type="password"]' ).wrap( '<span class="password-input"></span>' );
			// Add 'password-input' class to the password wrapper in checkout page.
			$( '.woocommerce form input' ).filter( ':password' ).parent( 'span' ).addClass( 'password-input' );
			$( '.password-input' ).append( '<span class="show-password-input"></span>' );

			$( '.show-password-input' ).on( 'click', function() {
				if ( $( this ).hasClass( 'display-password' ) ) {
					$( this ).removeClass( 'display-password' );
				} else {
					$( this ).addClass( 'display-password' );
				}
				if ( $( this ).hasClass( 'display-password' ) ) {
					$( this ).siblings( [ 'input[type="password"]' ] ).prop( 'type', 'text' );
				} else {
					$( this ).siblings( 'input[type="text"]' ).prop( 'type', 'password' );
				}
			} );*/
		}
	}( jQuery )
);
