<?php
defined( 'ABSPATH' ) || exit;

if ( ! class_exists( 'Minimog_Metabox' ) ) {
	class Minimog_Metabox {

		protected static $instance = null;

		public static function instance() {
			if ( null === self::$instance ) {
				self::$instance = new self();
			}

			return self::$instance;
		}

		public function initialize() {
			add_filter( 'insight_core_meta_boxes', array( $this, 'register_meta_boxes' ) );
		}

		/**
		 * Register Metabox
		 *
		 * @param $meta_boxes
		 *
		 * @return array
		 */
		public function register_meta_boxes( $meta_boxes ) {
			$page_registered_sidebars = Minimog_Helper::get_registered_sidebars( true );

			$general_options = array(
				array(
					'title'  => esc_attr__( 'Layout', 'minimog' ),
					'fields' => array(
						array(
							'id'    => 'site_class',
							'type'  => 'text',
							'title' => esc_html__( 'Body Class', 'minimog' ),
							'desc'  => esc_html__( 'Add a class name to body then refer to it in custom CSS.', 'minimog' ),
						),
						array(
							'id'      => 'settings_preset',
							'type'    => 'select',
							'title'   => esc_html__( 'Settings Preset', 'minimog' ),
							'default' => '',
							'options' => [
								''                    => esc_html__( 'None', 'minimog' ),
								'home-fashion-v9'     => esc_html__( 'Home Fashion v9', 'minimog' ),
								'home-watch'          => esc_html__( 'Home Watch', 'minimog' ),
								'home-bra'            => esc_html__( 'Home Bra', 'minimog' ),
								'home-case-phone'     => esc_html__( 'Home Case Phone', 'minimog' ),
								'home-backpack'       => esc_html__( 'Home Backpack', 'minimog' ),
								'home-drink'          => esc_html__( 'Home Drink', 'minimog' ),
								'home-stationery'     => esc_html__( 'Home Stationery', 'minimog' ),
								'home-sneaker'        => esc_html__( 'Home Sneaker', 'minimog' ),
								'home-art'            => esc_html__( 'Home Art', 'minimog' ),
								'home-toy'            => esc_html__( 'Home Toy', 'minimog' ),
								'home-living'         => esc_html__( 'Home Living', 'minimog' ),
								'home-glasses'        => esc_html__( 'Home Glasses', 'minimog' ),
								'home-plants'         => esc_html__( 'Home Plants', 'minimog' ),
								'home-activewear'     => esc_html__( 'Home Activewear', 'minimog' ),
								'home-coffee'         => esc_html__( 'Home Coffee', 'minimog' ),
								'home-bedding'        => esc_html__( 'Home Bedding', 'minimog' ),
								'home-print'          => esc_html__( 'Home Print', 'minimog' ),
								'home-furniture'      => esc_html__( 'Home Furniture', 'minimog' ),
								'home-skateboard'     => esc_html__( 'Home Skateboard', 'minimog' ),
								'home-pizza'          => esc_html__( 'Home Pizza', 'minimog' ),
								'home-jewelry'        => esc_html__( 'Home Jewelry', 'minimog' ),
								'home-supplyment'     => esc_html__( 'Home Supplyment', 'minimog' ),
								'home-bag'            => esc_html__( 'Home Bag', 'minimog' ),
								'home-nail-polish'    => esc_html__( 'Home Nail', 'minimog' ),
								'home-baby'           => esc_html__( 'Home Baby', 'minimog' ),
								'home-socks'          => esc_html__( 'Home Socks', 'minimog' ),
								'home-juice'          => esc_html__( 'Home Juice', 'minimog' ),
								'home-barber'         => esc_html__( 'Home Barber', 'minimog' ),
								'home-beauty'         => esc_html__( 'Home Beauty', 'minimog' ),
								'home-mirror'         => esc_html__( 'Home Mirror', 'minimog' ),
								'home-electronic'     => esc_html__( 'Home Electronic', 'minimog' ),
								'home-houseware'      => esc_html__( 'Home Houseware', 'minimog' ),
								'home-book'           => esc_html__( 'Home Book', 'minimog' ),
								'home-hat'            => esc_html__( 'Home Hat', 'minimog' ),
								'home-hand-santizer'  => esc_html__( 'Home Hand Santizer', 'minimog' ),
								'home-bathroom'       => esc_html__( 'Home Bathroom', 'minimog' ),
								'home-skincare'       => esc_html__( 'Home Skincare', 'minimog' ),
								'home-candles'        => esc_html__( 'Home Candles', 'minimog' ),
								'home-organic'        => esc_html__( 'Home Organic', 'minimog' ),
								'home-paint'          => esc_html__( 'Home Paint', 'minimog' ),
								'home-pan'            => esc_html__( 'Home Pan', 'minimog' ),
								'home-pet'            => esc_html__( 'Home Pet', 'minimog' ),
								'home-pod'            => esc_html__( 'Home POD', 'minimog' ),
								'home-gym-supplyment' => esc_html__( 'Home Gym Supplyment', 'minimog' ),
							],
						),
					),
				),
				array(
					'title'  => esc_attr__( 'Site Background', 'minimog' ),
					'fields' => array(
						array(
							'id'    => 'site_background_color',
							'type'  => 'color',
							'title' => esc_html__( 'Background Color', 'minimog' ),
							'desc'  => esc_html__( 'Controls the background color of the outer background area in boxed mode of this page.', 'minimog' ),
						),
						array(
							'id'    => 'site_background_image',
							'type'  => 'media',
							'title' => esc_html__( 'Background Image', 'minimog' ),
							'desc'  => esc_html__( 'Controls the background image of the outer background area in boxed mode of this page.', 'minimog' ),
						),
						array(
							'id'      => 'site_background_repeat',
							'type'    => 'select',
							'title'   => esc_html__( 'Background Repeat', 'minimog' ),
							'desc'    => esc_html__( 'Controls the background repeat of the outer background area in boxed mode of this page.', 'minimog' ),
							'options' => array(
								'no-repeat' => esc_attr__( 'No repeat', 'minimog' ),
								'repeat'    => esc_attr__( 'Repeat', 'minimog' ),
								'repeat-x'  => esc_attr__( 'Repeat X', 'minimog' ),
								'repeat-y'  => esc_attr__( 'Repeat Y', 'minimog' ),
							),
						),
						array(
							'id'      => 'site_background_attachment',
							'type'    => 'select',
							'title'   => esc_html__( 'Background Attachment', 'minimog' ),
							'desc'    => esc_html__( 'Controls the background attachment of the outer background area in boxed mode of this page.', 'minimog' ),
							'options' => array(
								''       => esc_attr__( 'Default', 'minimog' ),
								'fixed'  => esc_attr__( 'Fixed', 'minimog' ),
								'scroll' => esc_attr__( 'Scroll', 'minimog' ),
							),
						),
						array(
							'id'    => 'site_background_position',
							'type'  => 'text',
							'title' => esc_html__( 'Background Position', 'minimog' ),
							'desc'  => esc_html__( 'Controls the background position of the outer background area in boxed mode of this page.', 'minimog' ),
						),
						array(
							'id'    => 'site_background_size',
							'type'  => 'text',
							'title' => esc_html__( 'Background Size', 'minimog' ),
							'desc'  => esc_html__( 'Controls the background size of the outer background area in boxed mode of this page.', 'minimog' ),
						),
					),
				),
				array(
					'title'  => esc_html__( 'Top Bar', 'minimog' ),
					'fields' => array(
						array(
							'id'      => 'top_bar_type',
							'type'    => 'select',
							'title'   => esc_html__( 'Type', 'minimog' ),
							'desc'    => esc_html__( 'Select top bar type that displays on this page.', 'minimog' ),
							'default' => '',
							'options' => Minimog_Top_Bar::instance()->get_list( true ),
						),
						array(
							'id'      => 'top_bar_content_width',
							'type'    => 'select',
							'title'   => esc_html__( 'Content Width', 'minimog' ),
							'default' => '',
							'options' => Minimog_Site_Layout::instance()->get_container_wide_list( true ),
						),
						array(
							'id'    => 'top_bar_background_color',
							'type'  => 'color',
							'title' => esc_html__( 'Background', 'minimog' ),
						),
						array(
							'id'    => 'top_bar_text_color',
							'type'  => 'color',
							'title' => esc_html__( 'Text Color', 'minimog' ),
						),
						array(
							'id'    => 'top_bar_link_color',
							'type'  => 'color',
							'title' => esc_html__( 'Link Color', 'minimog' ),
						),
						array(
							'id'    => 'top_bar_link_hover_color',
							'type'  => 'color',
							'title' => esc_html__( 'Link Hover Color', 'minimog' ),
						),
						array(
							'id'    => 'top_bar_button_text_color',
							'type'  => 'color',
							'title' => esc_html__( 'Button Text Color', 'minimog' ),
						),
						array(
							'id'    => 'top_bar_button_background_color',
							'type'  => 'color',
							'title' => esc_html__( 'Button Background Color', 'minimog' ),
						),
						array(
							'id'    => 'top_bar_button_border_color',
							'type'  => 'color',
							'title' => esc_html__( 'Button Border Color', 'minimog' ),
						),
						array(
							'id'    => 'top_bar_button_hover_text_color',
							'type'  => 'color',
							'title' => esc_html__( 'Button Hover Text Color', 'minimog' ),
						),
						array(
							'id'    => 'top_bar_button_hover_background_color',
							'type'  => 'color',
							'title' => esc_html__( 'Button Hover Background Color', 'minimog' ),
						),
						array(
							'id'    => 'top_bar_button_hover_border_color',
							'type'  => 'color',
							'title' => esc_html__( 'Button Hover Border Color', 'minimog' ),
						),
						array(
							'id'      => 'top_bar_text',
							'type'    => 'textarea',
							'title'   => esc_html__( 'Custom Text', 'minimog' ),
							'desc'    => esc_html__( 'Custom top bar text. Leave blank to use default.', 'minimog' ),
							'default' => '',
						),
						array(
							'id'      => 'top_bar_text_style',
							'type'    => 'select',
							'title'   => esc_attr__( 'Text Style', 'minimog' ),
							'default' => '',
							'options' => [
								''   => esc_html__( 'Default', 'minimog' ),
								'01' => sprintf( esc_html__( 'Style %s', 'minimog' ), '01' ),
							],
						),
					),
				),
				array(
					'title'  => esc_html__( 'Header', 'minimog' ),
					'fields' => array(
						array(
							'id'      => 'header_type',
							'type'    => 'select',
							'title'   => esc_attr__( 'Header Type', 'minimog' ),
							'desc'    => esc_html__( 'Select header type that displays on this page.', 'minimog' ),
							'default' => '',
							'options' => Minimog_Header::instance()->get_list( true ),
						),
						array(
							'id'      => 'header_content_width',
							'type'    => 'select',
							'title'   => esc_html__( 'Content Width', 'minimog' ),
							'default' => '',
							'options' => Minimog_Site_Layout::instance()->get_container_wide_list( true ),
						),
						array(
							'id'      => 'header_above',
							'type'    => 'switch',
							'title'   => esc_attr__( 'Header Above', 'minimog' ),
							'default' => '',
							'options' => array(
								''  => esc_html__( 'Default', 'minimog' ),
								'0' => esc_html__( 'Hide', 'minimog' ),
								'1' => esc_html__( 'Show', 'minimog' ),
							),
						),
						array(
							'id'      => 'header_overlay',
							'type'    => 'switch',
							'title'   => esc_attr__( 'Header Overlay', 'minimog' ),
							'default' => '',
							'options' => array(
								''  => esc_html__( 'Default', 'minimog' ),
								'0' => esc_html__( 'No', 'minimog' ),
								'1' => esc_html__( 'Yes', 'minimog' ),
							),
						),
						array(
							'id'      => 'header_skin',
							'type'    => 'switch',
							'title'   => esc_attr__( 'Header Skin', 'minimog' ),
							'default' => '',
							'options' => array(
								''      => esc_html__( 'Default', 'minimog' ),
								'dark'  => esc_html__( 'Dark', 'minimog' ),
								'light' => esc_html__( 'Light', 'minimog' ),
							),
						),
						array(
							'id'      => 'header_shadow',
							'type'    => 'switch',
							'title'   => esc_attr__( 'Header Shadow', 'minimog' ),
							'default' => '',
							'options' => array(
								''     => esc_html__( 'Default', 'minimog' ),
								'none' => esc_html__( 'None', 'minimog' ),
							),
						),
						array(
							'id'      => 'header_background',
							'type'    => 'switch',
							'title'   => esc_attr__( 'Header Background', 'minimog' ),
							'default' => '',
							'options' => array(
								''     => esc_html__( 'Default', 'minimog' ),
								'none' => esc_html__( 'None', 'minimog' ),
							),
						),
						array(
							'id'      => 'menu_display',
							'type'    => 'select',
							'title'   => esc_html__( 'Primary menu', 'minimog' ),
							'desc'    => esc_html__( 'Select which menu displays on this page.', 'minimog' ),
							'default' => '',
							'options' => Minimog_Nav_Menu::get_all_menus(),
						),
						array(
							'id'      => 'menu_one_page',
							'type'    => 'switch',
							'title'   => esc_attr__( 'One Page Menu', 'minimog' ),
							'default' => '0',
							'options' => array(
								'0' => esc_attr__( 'Disable', 'minimog' ),
								'1' => esc_attr__( 'Enable', 'minimog' ),
							),
						),
					),
				),
				array(
					'title'  => esc_html__( 'Page Title Bar', 'minimog' ),
					'fields' => array(
						array(
							'id'      => 'page_title_bar_layout',
							'type'    => 'select',
							'title'   => esc_html__( 'Layout', 'minimog' ),
							'default' => '',
							'options' => Minimog_Title_Bar::instance()->get_list( true ),
						),
						array(
							'id'      => 'page_title_bar_container_size',
							'type'    => 'select',
							'title'   => esc_html__( 'Container Size', 'minimog' ),
							'default' => '',
							'options' => Minimog_Site_Layout::instance()->get_container_wide_list( true ),
						),
						array(
							'id'    => 'page_title_bar_bottom_spacing',
							'type'  => 'text',
							'title' => esc_html__( 'Spacing', 'minimog' ),
							'desc'  => esc_html__( 'Controls the bottom spacing of title bar of this page. Enter value including any valid CSS unit. For e.g: 50px. Leave blank to use global setting.', 'minimog' ),
						),
						array(
							'id'      => 'page_title_bar_background_color',
							'type'    => 'color',
							'title'   => esc_html__( 'Background Color', 'minimog' ),
							'default' => '',
						),
						array(
							'id'      => 'page_title_bar_background',
							'type'    => 'media',
							'title'   => esc_html__( 'Background Image', 'minimog' ),
							'default' => '',
						),
						array(
							'id'      => 'page_title_bar_background_overlay',
							'type'    => 'color',
							'title'   => esc_html__( 'Background Overlay', 'minimog' ),
							'default' => '',
						),
						array(
							'id'    => 'page_title_bar_custom_heading',
							'type'  => 'text',
							'title' => esc_html__( 'Custom Heading Text', 'minimog' ),
							'desc'  => esc_html__( 'Insert custom heading for the page title bar. Leave blank to use default.', 'minimog' ),
						),
					),
				),
				array(
					'title'  => esc_html__( 'Sidebars', 'minimog' ),
					'fields' => array(
						array(
							'id'      => 'page_sidebar_1',
							'type'    => 'select',
							'title'   => esc_html__( 'Sidebar 1', 'minimog' ),
							'desc'    => esc_html__( 'Select sidebar 1 that will display on this page.', 'minimog' ),
							'default' => 'default',
							'options' => $page_registered_sidebars,
						),
						array(
							'id'      => 'page_sidebar_2',
							'type'    => 'select',
							'title'   => esc_html__( 'Sidebar 2', 'minimog' ),
							'desc'    => esc_html__( 'Select sidebar 2 that will display on this page.', 'minimog' ),
							'default' => 'default',
							'options' => $page_registered_sidebars,
						),
						array(
							'id'      => 'page_sidebar_position',
							'type'    => 'switch',
							'title'   => esc_html__( 'Sidebar Position', 'minimog' ),
							'desc'    => esc_html__( 'Select position of Sidebar 1 for this page. If sidebar 2 is selected, it will display on the opposite side.', 'minimog' ),
							'default' => 'default',
							'options' => Minimog_Helper::get_list_sidebar_positions( true ),
						),
						array(
							'id'      => 'page_single_sidebar_width',
							'type'    => 'text',
							'title'   => esc_html__( 'Single Sidebar Width', 'minimog' ),
							'desc'    => esc_html__( 'Controls the width of the sidebar when only one sidebar is present. Input value as % unit. For e.g: 33.33333. Leave blank to use global setting.', 'minimog' ),
							'default' => '',
						),
						array(
							'id'      => 'page_single_sidebar_offset',
							'type'    => 'text',
							'title'   => esc_html__( 'Single Sidebar Offset', 'minimog' ),
							'desc'    => esc_html__( 'Controls the offset of the sidebar when only one sidebar is present. Enter value including any valid CSS unit. For e.g: 70px. Leave blank to use global setting.', 'minimog' ),
							'default' => '',
						),
						array(
							'id'      => 'page_sidebar_style',
							'type'    => 'select',
							'title'   => esc_html__( 'Sidebar Style', 'minimog' ),
							'default' => '',
							'options' => Minimog_Sidebar::instance()->get_supported_style_options( [ 'default' => true ] ),
						),
					),
				),
				array(
					'title'  => esc_html__( 'Sliders', 'minimog' ),
					'fields' => array(
						array(
							'id'      => 'revolution_slider',
							'type'    => 'select',
							'title'   => esc_html__( 'Revolution Slider', 'minimog' ),
							'desc'    => esc_html__( 'Select the unique name of the slider.', 'minimog' ),
							'options' => Minimog_Helper::get_list_revslider(),
						),
						array(
							'id'      => 'slider_position',
							'type'    => 'select',
							'title'   => esc_html__( 'Slider Position', 'minimog' ),
							'default' => 'below',
							'options' => array(
								'above' => esc_attr__( 'Above Header', 'minimog' ),
								'below' => esc_attr__( 'Below Header', 'minimog' ),
							),
						),
					),
				),
				array(
					'title'  => esc_html__( 'Footer', 'minimog' ),
					'fields' => array(
						array(
							'id'      => 'footer_enable',
							'type'    => 'select',
							'title'   => esc_html__( 'Footer Enable', 'minimog' ),
							'default' => '',
							'options' => array(
								''     => esc_html__( 'Yes', 'minimog' ),
								'none' => esc_html__( 'No', 'minimog' ),
							),
						),
					),
				),
			);

			// Page.
			$meta_boxes[] = array(
				'id'         => 'insight_page_options',
				'title'      => esc_html__( 'Page Options', 'minimog' ),
				'post_types' => array( 'page' ),
				'context'    => 'normal',
				'priority'   => 'high',
				'fields'     => array(
					array(
						'type'  => 'tabpanel',
						'items' => $general_options,
					),
				),
			);

			// Post.
			$meta_boxes[] = array(
				'id'         => 'insight_post_options',
				'title'      => esc_html__( 'Page Options', 'minimog' ),
				'post_types' => array( 'post' ),
				'context'    => 'normal',
				'priority'   => 'high',
				'fields'     => array(
					array(
						'type'  => 'tabpanel',
						'items' => array_merge( array(
							array(
								'title'  => esc_html__( 'Post', 'minimog' ),
								'fields' => array(
									array(
										'id'      => 'post_entry_feature',
										'type'    => 'switch',
										'title'   => esc_html__( 'Featured Image', 'minimog' ),
										'default' => 'default',
										'options' => [
											'default' => esc_html__( 'Default', 'minimog' ),
											'1'       => esc_html__( 'Show', 'minimog' ),
											'0'       => esc_html__( 'Hide', 'minimog' ),
										],
									),
									array(
										'id'    => 'post_gallery',
										'type'  => 'gallery',
										'title' => esc_html__( 'Gallery Format', 'minimog' ),
									),
									array(
										'id'    => 'post_video',
										'type'  => 'text',
										'title' => esc_html__( 'Video URL', 'minimog' ),
										'desc'  => esc_html__( 'Input the url of video vimeo or youtube. For e.g: https://www.youtube.com/watch?v=9No-FiEInLA', 'minimog' ),
									),
									array(
										'id'    => 'post_audio',
										'type'  => 'textarea',
										'title' => esc_html__( 'Audio Format', 'minimog' ),
									),
									array(
										'id'    => 'post_quote_text',
										'type'  => 'text',
										'title' => esc_html__( 'Quote Format - Source Text', 'minimog' ),
									),
									array(
										'id'    => 'post_quote_name',
										'type'  => 'text',
										'title' => esc_html__( 'Quote Format - Source Name', 'minimog' ),
									),
									array(
										'id'    => 'post_quote_position',
										'type'  => 'text',
										'title' => esc_html__( 'Quote Format - Source Position', 'minimog' ),
									),
									array(
										'id'    => 'post_quote_url',
										'type'  => 'text',
										'title' => esc_html__( 'Quote Format - Source Url', 'minimog' ),
									),
									array(
										'id'    => 'post_link',
										'type'  => 'text',
										'title' => esc_html__( 'Link Format', 'minimog' ),
									),
								),
							),
						), $general_options ),
					),
				),
			);

			return apply_filters( 'minimog/meta_box/page_options', $meta_boxes, $general_options );
		}

	}

	Minimog_Metabox::instance()->initialize();
}
