<?php
defined( 'ABSPATH' ) || exit;

/**
 * Plugin installation and activation for WordPress themes
 */
if ( ! class_exists( 'Minimog_Register_Plugins' ) ) {
	class Minimog_Register_Plugins {

		protected static $instance = null;

		public static function instance() {
			if ( null === self::$instance ) {
				self::$instance = new self();
			}

			return self::$instance;
		}

		function initialize() {
			add_filter( 'insight_core_tgm_plugins', array( $this, 'register_required_plugins' ) );
		}

		public function register_required_plugins( $plugins ) {
			/*
			 * Array of plugin arrays. Required keys are name and slug.
			 * If the source is NOT from the .org repo, then source is also required.
			 */
			$new_plugins = array(
				array(
					'name'     => esc_html__( 'Insight Core', 'minimog' ),
					'slug'     => 'insight-core',
					'source'   => Minimog_Google_Manager::get_google_driver_url( '1n2ecxWN3T0eTafoBB9QMuZt_mHEfugYb' ),
					'version'  => '2.4.4',
					'required' => true,
				),
				array(
					'name'     => esc_html__( 'Redux Framework', 'minimog' ),
					'slug'     => 'redux-framework',
					'required' => true,
				),
				array(
					'name'     => esc_html__( 'Elementor', 'minimog' ),
					'slug'     => 'elementor',
					'required' => true,
				),
				array(
					'name'     => esc_html__( 'Thememove Addons For Elementor', 'minimog' ),
					'slug'     => 'tm-addons-for-elementor',
					'source'   => Minimog_Google_Manager::get_google_driver_url( '1HRQrTyXBOhl9k1QSznbwDI3UbzqqI5PJ' ),
					'version'  => '1.0.1',
					'required' => true,
				),
				array(
					'name'    => esc_html__( 'Revolution Slider', 'minimog' ),
					'slug'    => 'revslider',
					'source'  => Minimog_Google_Manager::get_google_driver_url( '1AM1FS_OecPXtKm1p8oK-3cEhMxOYxXdr' ),
					'version' => '6.5.20',
				),
				array(
					'name'    => esc_html__( 'WPForms', 'minimog' ),
					'slug'    => 'wpforms-lite',
					'source'  => Minimog_Google_Manager::get_google_driver_url( '188-LCyLJTIKpClf5lKCF1FlBGwWpDoDi' ),
					'version' => '1.7.3.1',
				),
				array(
					'name' => esc_html__( 'WooCommerce', 'minimog' ),
					'slug' => 'woocommerce',
				),
				array(
					'name'    => esc_html__( 'Insight Swatches', 'minimog' ),
					'slug'    => 'insight-swatches',
					'source'  => Minimog_Google_Manager::get_google_driver_url( '1IvIQkzvSX9-yG8F92kymG6jjRujkAH4t' ),
					'version' => '1.3.1',
				),
				array(
					'name'    => esc_html__( 'Insight Product Brands', 'minimog' ),
					'slug'    => 'insight-product-brands',
					'source'  => Minimog_Google_Manager::get_google_driver_url( '1R1G4LZS3zxEQW-mM4_iZojqVRqcljZD5' ),
					'version' => '1.0.0',
				),
				array(
					'name' => esc_html__( 'Conditional Discounts for WooCommerce', 'minimog' ),
					'slug' => 'woo-advanced-discounts',
				),
				array(
					'name'    => esc_html__( 'Sales Countdown Timer (Premium)', 'minimog' ),
					'slug'    => 'sctv-sales-countdown-timer',
					'source'  => Minimog_Google_Manager::get_google_driver_url( '15F_wCLj56-LOngvOgD-yjLRY0JfS-yjy' ),
					'version' => '1.0.6.1',
				),
				array(
					'name'    => esc_html__( 'Multi Currency for WooCommerce (Premium)', 'minimog' ),
					'slug'    => 'woocommerce-multi-currency',
					'source'  => Minimog_Google_Manager::get_google_driver_url( '1q1tIqFyMwy9duz6jIDGnW8Xr739AsWov' ),
					'version' => '2.1.32.1',
				),
				array(
					'name'    => esc_html__( 'WPC Smart Compare for WooCommerce (Premium)', 'minimog' ),
					'slug'    => 'woo-smart-compare',
					'source'  => Minimog_Google_Manager::get_google_driver_url( '19yTd6fUHhL3Fv70dY-i8mZMMldKtvja4' ),
					'version' => '4.2.8',
				),
				array(
					'name'    => esc_html__( 'WPC Smart Wishlist for WooCommerce (Premium)', 'minimog' ),
					'slug'    => 'woo-smart-wishlist',
					'source'  => Minimog_Google_Manager::get_google_driver_url( '1_AEMJLVWJIf14j5PtMGyRl7wA9QStq-D' ),
					'version' => '2.9.6',
				),
				array(
					'name'    => esc_html__( 'WPC Smart Notification for WooCommerce (Premium)', 'minimog' ),
					'slug'    => 'wpc-smart-notification',
					'source'  => Minimog_Google_Manager::get_google_driver_url( '1XorfsKZ7PYz1CcxQTQeQldYeWBUacANs' ),
					'version' => '1.2.4',
				),
				array(
					'name'    => esc_html__( 'WPC Frequently Bought Together for WooCommerce (Premium)', 'minimog' ),
					'slug'    => 'woo-bought-together-premium',
					'source'  => Minimog_Google_Manager::get_google_driver_url( '1xT__hQvcyGRuzIKbMpIyfveUWheHsVAj' ),
					'version' => '4.2.0',
				),
				array(
					'name'    => esc_html__( 'WPC Product Bundles for WooCommerce (Premium)', 'minimog' ),
					'slug'    => 'woo-product-bundle-premium',
					'source'  => Minimog_Google_Manager::get_google_driver_url( '1JFTbt1L_j4TZvf36r3B4qVpe14BDIKsL' ),
					'version' => '6.0.9',
				),
				array(
					'name'    => esc_html__( 'WPC Product Tabs for WooCommerce (Premium)', 'minimog' ),
					'slug'    => 'wpc-product-tabs-premium',
					'source'  => Minimog_Google_Manager::get_google_driver_url( '1GffIwghJvkPjclxPpOfBedrEUKbecLv4' ),
					'version' => '1.5.2',
				),
				array(
					'name'    => esc_html__( 'Shoppable Images', 'minimog' ),
					'slug'    => 'mabel-shoppable-images-lite',
					'source'  => Minimog_Google_Manager::get_google_driver_url( '1kYgyy0zZ-Q4Dn8PLHbrfXlIC86i0VRpD' ),
					'version' => '1.1.8',
				),
				array(
					'name' => esc_html__( 'WordPress Social Login', 'minimog' ),
					'slug' => 'miniorange-login-openid',
				),
				array(
					'name' => esc_html__( 'User Profile Picture', 'minimog' ),
					'slug' => 'metronet-profile-picture',
				),
				array(
					'name' => esc_html__( 'DCO Comment Attachment', 'minimog' ),
					'slug' => 'dco-comment-attachment',
				),
			);

			$plugins = array_merge( $plugins, $new_plugins );

			return $plugins;
		}
	}

	Minimog_Register_Plugins::instance()->initialize();
}
