<?php
defined( 'ABSPATH' ) || exit;

if ( ! class_exists( 'Minimog_Promo_Popup' ) ) {

	class Minimog_Promo_Popup {

		protected static $instance = null;

		public static function instance() {
			if ( null === self::$instance ) {
				self::$instance = new self();
			}

			return self::$instance;
		}

		function initialize() {
			add_action( 'wp_footer', [ $this, 'output_promo_popup' ] );

			// Promo popup confirm.
			add_action( 'wp_ajax_minimog_promo_popup_confirm', [ $this, 'promo_popup_confirm' ] );
			add_action( 'wp_ajax_nopriv_minimog_promo_popup_confirm', [ $this, 'promo_popup_confirm' ] );
		}

		public function is_active() {
			$confirm = isset( $_COOKIE['promo_popup_confirm'] ) ? 'yes' : 'no';
			$enable  = Minimog::setting( 'promo_popup_enable' );

			if ( $enable === '1' && $confirm === 'no' ) {
				return true;
			}

			return false;
		}

		public function output_promo_popup() {
			if ( $this->is_active() ) {
				minimog_load_template( 'promo-popup' );
			}
		}

		public function promo_popup_confirm() {
			$time = apply_filters( 'minimog/promo_popup/cookie_expires_time', MONTH_IN_SECONDS );
			$path = COOKIEPATH;

			if ( is_multisite() && function_exists( 'get_blog_details' ) ) {
				$path = get_blog_details()->path;
			}

			$result = setcookie( 'promo_popup_confirm', 'yes', time() + $time, $path, COOKIE_DOMAIN );

			if ( $result ) {
				wp_send_json_success();
			}

			wp_send_json_error();
		}
	}

	Minimog_Promo_Popup::instance()->initialize();
}
