<?php
defined( 'ABSPATH' ) || exit;

class Minimog {

	const FONT_JOST             = 'Jost';
	const FONT_SATOSHI          = 'Satoshi';
	const FONT_NEWYORK          = 'NewYork';
	const FONT_GORDITA          = 'Gordita';
	const FONT_BUTLER           = 'Butler';
	const FONT_CYRENE           = 'Cyrene';
	const FONT_WORTHBITES_ROUGH = 'WorthbitesRough';
	const FONT_CANELA           = 'Canela';

	const PRIMARY_FONT           = self::FONT_JOST;
	const SECONDARY_FONT         = self::FONT_JOST;
	const PRIMARY_COLOR          = '#DA3F3F';
	const SECONDARY_COLOR        = '#000';
	const PRIMARY_BG_COLOR       = '#F5F1E9';
	const GRADIENT_COLOR_1       = '#20AD96';
	const GRADIENT_COLOR_2       = '#3F3A64';
	const HEADING_COLOR          = '#000';
	const TEXT_COLOR             = '#666';
	const TEXT_LIGHTEN_COLOR     = '#ababab';
	const TYPOGRAPHY_BODY_WEIGHT = '400';
	const COMMENT_AVATAR_SIZE    = 70;

	public static function is_tablet() {
		if ( ! class_exists( 'Mobile_Detect' ) ) {
			return false;
		}

		return Mobile_Detect::instance()->isTablet();
	}

	public static function is_mobile() {
		if ( ! class_exists( 'Mobile_Detect' ) ) {
			return false;
		}

		if ( self::is_tablet() ) {
			return false;
		}

		return Mobile_Detect::instance()->isMobile();
	}

	public static function is_handheld() {
		return ( self::is_mobile() || self::is_tablet() );
	}

	public static function is_desktop() {
		return ! self::is_handheld();
	}

	public static function elementor_is_edit_mode() {
		if ( class_exists( '\Elementor\Plugin' ) && \Elementor\Plugin::$instance->editor->is_edit_mode() ) {
			return true;
		}

		return false;
	}

	/**
	 * Get theme setting
	 *
	 * @param string $option_name
	 * @param string $default
	 *
	 * @return mixed
	 */
	public static function setting( $option_name = '', $default = '' ) {
		global $minimog_options;

		if ( isset( $minimog_options[ $option_name ] ) ) {
			return $minimog_options[ $option_name ];
		}

		if ( '' !== $default ) {
			return $default;
		}

		return Minimog_Redux::instance()->get_default_setting( $option_name, $default );
	}

	/**
	 * Primary Menu
	 */
	public static function menu_primary( $args = array() ) {
		$menu_class = 'menu__container sm sm-simple';

		if ( is_rtl() ) {
			$menu_class .= ' sm-rtl';
		}

		$smartmenu_settings = [
			'subMenusSubOffsetX' => -18,
			'subMenusSubOffsetY' => -17,
		];

		$defaults = array(
			'theme_location' => 'primary',
			'container'      => 'ul',
			'menu_class'     => $menu_class,
			'menu_id'        => 'menu-primary', // Change this id also need to change in global variable below.
			'extra_class'    => '',
			'items_wrap'     => '<ul id="%1$s" class="%2$s" data-sm-options="' . esc_attr( wp_json_encode( $smartmenu_settings ) ) . '">%3$s</ul>',
		);

		if ( $defaults['extra_class'] ) {
			$defaults['menu_class'] .= ' ' . $defaults['extra_class'];
		}

		$args = wp_parse_args( $args, $defaults );

		if ( has_nav_menu( 'primary' ) && class_exists( 'Minimog_Walker_Nav_Menu' ) ) {
			$args['walker'] = new Minimog_Walker_Nav_Menu;
		}

		$menu = Minimog_Helper::get_post_meta( 'menu_display', '' );

		if ( $menu !== '' ) {
			$args['menu'] = $menu;
		}

		/**
		 * Nav menu render need many works.
		 * Cache it & used for mobile version to get the best performance.
		 *
		 * @see Minimog::menu_mobile_primary()
		 */
		global $minimog_primary_menu;

		ob_start();

		wp_nav_menu( $args );

		$minimog_primary_menu = ob_get_clean();

		echo '' . $minimog_primary_menu;
	}

	/**
	 * Mobile Menu
	 */
	public static function menu_mobile_primary() {
		global $minimog_primary_menu;

		$pattern = '/<ul\s[^>]*id=\"menu-primary\"[^>]*>/';

		$mobile_menu = preg_replace( $pattern, '<ul id="mobile-menu-primary" class="menu__container">', $minimog_primary_menu );

		echo '' . $mobile_menu;
		unset( $GLOBALS['minimog_primary_menu'] );
	}

	/**
	 * Logo
	 */
	public static function branding_logo( $args = array() ) {
		$defaults = [
			// Used when get specify skin. Eg: light, dark
			'skin' => '',
		];
		$args     = wp_parse_args( $args, $defaults );

		$has_both_skin    = false;
		$sticky_logo_skin = Minimog::setting( 'header_sticky_logo' );
		$header_logo_skin = Minimog_Global::instance()->get_header_skin();
		$display_logos    = [];

		if ( in_array( $args['skin'], [ 'dark', 'light' ] ) ) {
			$display_logos["{$args['skin']}"] = [];
		} else {
			if ( $sticky_logo_skin !== $header_logo_skin || is_page_template( 'templates/one-page-scroll.php' ) ) {
				$display_logos = array(
					'dark'  => [],
					'light' => [],
				);
			} else {
				$display_logos = 'dark' === $header_logo_skin ? array( 'dark' => [] ) : array( 'light' => [] );
			}
		}

		$lazy_load_enable = Minimog::setting( 'image_lazy_load_enable' ) && ! Minimog::elementor_is_edit_mode();
		$logo_width       = intval( Minimog::setting( 'logo_width' ) );
		$retina_width     = $logo_width * 2;
		$alt              = get_bloginfo( 'name', 'display' );

		if ( isset( $display_logos['dark'] ) ) {
			$logo_dark = Minimog::setting( 'logo_dark' );

			if ( ! empty( $logo_dark['id'] ) ) {
				$logo_dark_url = Minimog_Image::get_attachment_url_by_id( array(
					'id'   => $logo_dark['id'],
					'size' => "{$retina_width}x9999",
					'crop' => false,
				) );
			} else {
				$logo_dark_url = $logo_dark['url'];
			}

			$display_logos['dark'] = [
				'src'   => $logo_dark_url,
				'alt'   => $alt,
				'class' => 'logo dark-logo',
				'width' => $logo_width,
			];
		}

		if ( isset( $display_logos['light'] ) ) {
			$logo_light = Minimog::setting( 'logo_light' );

			if ( ! empty( $logo_light['id'] ) ) {
				$logo_light_url = Minimog_Image::get_attachment_url_by_id( array(
					'id'   => $logo_light['id'],
					'size' => "{$retina_width}x9999",
					'crop' => false,
				) );
			} else {
				$logo_light_url = $logo_light['url'];
			}

			$display_logos['light'] = [
				'src'   => $logo_light_url,
				'alt'   => $alt,
				'class' => 'logo light-logo',
				'width' => $logo_width,
			];
		}

		$logos_html = '';

		foreach ( $display_logos as $display_logo ) {
			$image_size = Minimog_Image::get_image_size( $display_logo['src'] );
			if ( ! empty( $image_size ) ) {
				$image_width  = $image_size[0];
				$image_height = $image_size[1];
			} else {
				$image_width  = $display_logo['width'];
				$image_height = 42;
			}

			$logo_class = $display_logo['class'];

			if ( $lazy_load_enable ) {
				$display_logo['class']    .= ' ll-image';
				$display_logo['data-src'] = $display_logo['src'];
				$display_logo['src']      = MINIMOG_THEME_IMAGE_URI . '/placeholder-transparent.png';
			}

			$logo_html = Minimog_Image::build_img_tag( $display_logo );

			if ( $lazy_load_enable ) {
				$logos_html .= Minimog_Image::build_lazy_img_tag( $logo_html, $image_width, $image_height, $logo_class );
			} else {
				$logos_html .= $logo_html;
			}
		}
		?>
		<a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php echo '' . $logos_html; ?></a>
		<?php
	}

	/**
	 * Adds custom attributes to the body tag.
	 */
	public static function body_attributes() {
		$attrs = apply_filters( 'minimog/body_attributes', array() );

		$attrs_string = '';
		if ( ! empty( $attrs ) ) {
			foreach ( $attrs as $attr => $value ) {
				$attrs_string .= " {$attr}=" . '"' . esc_attr( $value ) . '"';
			}
		}

		echo '' . $attrs_string;
	}

	/**
	 * Adds custom classes to the branding.
	 */
	public static function branding_class( $class = '' ) {
		$classes = array( 'branding' );

		if ( ! empty( $class ) ) {
			if ( ! is_array( $class ) ) {
				$class = preg_split( '#\s+#', $class );
			}
			$classes = array_merge( $classes, $class );
		} else {
			// Ensure that we always coerce class to being an array.
			$class = array();
		}

		$classes = apply_filters( 'minimog/branding/class', $classes, $class );

		echo 'class="' . esc_attr( join( ' ', $classes ) ) . '"';
	}

	/**
	 * Adds custom classes to the navigation.
	 */
	public static function navigation_class( $class = '' ) {
		$classes = array( 'navigation page-navigation' );

		if ( ! empty( $class ) ) {
			if ( ! is_array( $class ) ) {
				$class = preg_split( '#\s+#', $class );
			}
			$classes = array_merge( $classes, $class );
		} else {
			// Ensure that we always coerce class to being an array.
			$class = array();
		}

		$classes = apply_filters( 'minimog/navigation/class', $classes, $class );

		echo 'class="' . esc_attr( join( ' ', $classes ) ) . '"';
	}
}
