<?php

namespace Minimog\Woo;

defined( 'ABSPATH' ) || exit;

class Admin_Settings {

	protected static $instance = null;

	public static function instance() {
		if ( null === self::$instance ) {
			self::$instance = new self();
		}

		return self::$instance;
	}

	public function initialize() {
		add_filter( 'woocommerce_general_settings', [ $this, 'add_general_settings' ] );

		add_filter( 'woocommerce_shipping_settings', [ $this, 'add_shipping_settings' ] );

		add_filter( 'insight_core_export_woocommerce_options', [ $this, 'add_export_options' ] );
	}

	public function add_general_settings( $settings ) {
		$count = count( $settings );

		$new_settings = array(
			[
				'title'           => __( 'Decimal no zeroes', 'minimog' ),
				// WPCS: XSS ok.
				'desc'            => __( 'Trim all zeros at the last from decimal', 'minimog' ),
				// WPCS: XSS ok.
				'id'              => 'woocommerce_price_decimal_no_zeroes',
				'type'            => 'checkbox',
				'default'         => 'no',
				'show_if_checked' => 'yes',
				'autoload'        => false,

			],
		);

		\Minimog_Helper::array_insert( $settings, $count - 1, $new_settings );

		return $settings;
	}

	public function add_shipping_settings( $settings ) {
		$count = count( $settings );

		$new_settings = array(
			[
				'title'             => __( 'Delivery Time Range', 'minimog' ),
				// WPCS: XSS ok.
				'desc'              => __( 'Set up estimated average shipping delivery time.', 'minimog' ),
				// WPCS: XSS ok.
				'id'                => 'woocommerce_shipping_delivery_time',
				'type'              => 'number',
				'placeholder'       => '7',
				'autoload'          => false,
				'suffix'            => __( 'day(s)', 'minimog' ),
				// WPCS: XSS ok.
				'custom_attributes' => [
					'min' => 0,
				],
			],
		);

		\Minimog_Helper::array_insert( $settings, $count - 1, $new_settings );

		return $settings;
	}

	public function add_export_options( $options ) {
		$new_options = [
			'woocommerce_price_decimal_no_zeroes',
			'woocommerce_shipping_delivery_time',
		];

		return array_merge( $options, $new_options );
	}
}

Admin_Settings::instance()->initialize();
