<?php

namespace Minimog\Woo;

defined( 'ABSPATH' ) || exit;

class Enqueue {
	protected static $instance = null;

	public static function instance() {
		if ( null === self::$instance ) {
			self::$instance = new self();
		}

		return self::$instance;
	}

	public function initialize() {
		// Disable woocommerce all styles.
		add_filter( 'woocommerce_enqueue_styles', '__return_empty_array' );

		add_action( 'wp_enqueue_scripts', [ $this, 'frontend_scripts' ] );
	}

	public function frontend_scripts() {
		$min = \Minimog_Enqueue::instance()->get_min_suffix();
		$rtl = \Minimog_Enqueue::instance()->get_rtl_suffix();

		// Remove prettyPhoto, default light box of woocommerce.
		wp_dequeue_script( 'prettyPhoto' );
		wp_dequeue_script( 'prettyPhoto-init' );
		wp_dequeue_style( 'woocommerce_prettyPhoto_css' );

		/**
		 * Remove style from extension Check Pincode/Zipcode
		 */
		wp_dequeue_style( 'WPCC_front_style' );

		// Swatches.
		wp_dequeue_style( 'isw-frontend' );

		// Many code unused then we will rewrite this script.
		wp_deregister_script( 'wc-single-product' );

		// De-register this script caused make other scripts like wc-cart or wc-checkout can't load by them depend on.
		//if ( ! is_checkout() ) {
		wp_deregister_script( 'woocommerce' );
		//}

		wp_register_style( 'minimog-woocommerce', MINIMOG_THEME_URI . "/woocommerce{$rtl}{$min}.css", null, MINIMOG_THEME_VERSION );

		wp_register_script( 'minimog-woo-general', MINIMOG_THEME_URI . "/assets/js/woo/general{$min}.js", [
			'jquery',
			'js-cookie',
		], MINIMOG_THEME_VERSION, true );

		/**
		 * Used edition version for better performance.
		 */
		wp_deregister_script( 'wc-cart-fragments' );
		wp_register_script( 'wc-cart-fragments', MINIMOG_THEME_URI . "/assets/js/woo/cart-fragments{$min}.js", [
			'jquery',
			'js-cookie',
		], MINIMOG_THEME_VERSION, true );

		/**
		 * Used edition version for better performance.
		 */
		wp_deregister_script( 'wc-add-to-cart-variation' );
		wp_register_script( 'wc-add-to-cart-variation', MINIMOG_THEME_URI . "/assets/js/woo/add-to-cart-variation{$min}.js", [
			'jquery',
			'wp-util',
			'jquery-blockui',
		], MINIMOG_THEME_VERSION, true );

		/**
		 * Used edition version for better performance.
		 * Used same handle name to get localize script.
		 */
		wp_deregister_script( 'wc-checkout' );
		wp_register_script( 'wc-checkout', MINIMOG_THEME_URI . "/assets/js/woo/checkout{$min}.js", [ 'jquery' ], MINIMOG_THEME_VERSION, true );

		wp_register_script( 'minimog-woo-cart', MINIMOG_THEME_URI . "/assets/js/woo/cart{$min}.js", [ 'jquery' ], MINIMOG_THEME_VERSION, true );
		wp_register_script( 'minimog-woo-single', MINIMOG_THEME_URI . "/assets/js/woo/single{$min}.js", [ 'jquery' ], MINIMOG_THEME_VERSION, true );
		wp_register_script( 'minimog-woo-questions', MINIMOG_THEME_URI . "/assets/js/woo/product-questions{$min}.js", [
			'jquery',
		], MINIMOG_THEME_VERSION, true );

		$fly_cart_depends = [
			'jquery',
			'minimog-quantity-button',
		];

		if ( '1' === \Minimog::setting( 'shopping_cart_countdown_enable' ) ) {
			$fly_cart_depends[] = 'minimog-countdown-timer';
		}

		wp_register_script( 'minimog-woo-fly-cart', MINIMOG_THEME_URI . "/assets/js/woo/fly-cart{$min}.js", $fly_cart_depends, MINIMOG_THEME_VERSION, true );

		$woo_variables = array(
			'wc_ajax_url'         => \WC_AJAX::get_endpoint( '%%endpoint%%' ),
			'apply_coupon_nonce'  => wp_create_nonce( 'apply-coupon' ),
			'remove_coupon_nonce' => wp_create_nonce( 'remove-coupon' ),
		);
		wp_localize_script( 'minimog-woo-general', '$minimogWoo', $woo_variables );

		wp_enqueue_style( 'minimog-woocommerce' );

		if ( '1' === \Minimog::setting( 'shop_quick_view_enable' ) ) {
			wp_enqueue_script( 'minimog-modal' );

			/**
			 * Enable ajax add to cart variation in Quick View popup on all pages.
			 */
			wp_enqueue_script( 'wc-add-to-cart-variation' );

			// Quick view need change quantity.
			wp_enqueue_script( 'minimog-quantity-button' );

			wp_enqueue_script( 'minimog-nice-select' );
		}

		wp_enqueue_script( 'minimog-woo-general' );

		/**
		 * Calculate Shipping for Fly Cart
		 * Don't used WC()->cart->needs_shipping()
		 * because scripts won't load when cart empty
		 **/
		if ( 'yes' === get_option( 'woocommerce_enable_shipping_calc' )
		     && wc_shipping_enabled() ) {
			// Optional for better select.
			wp_enqueue_script( 'selectWoo' );
			wp_enqueue_style( 'select2' );

			// Required.
			wp_enqueue_script( 'wc-country-select' );
		}

		wp_enqueue_script( 'minimog-woo-fly-cart' );

		if ( \Minimog_Woo::instance()->is_product_archive() ) {
			wp_enqueue_script( 'minimog-nice-select' );
			wp_enqueue_script( 'minimog-grid-layout' );
			wp_enqueue_script( 'minimog-common-archive' );
		}

		if ( is_cart() ) {
			wp_enqueue_script( 'minimog-woo-cart' );
			wp_enqueue_script( 'minimog-quantity-button' );
		}

		if ( is_checkout() ) {
			wp_enqueue_script( 'minimog-woo-cart' );
			wp_enqueue_script( 'wc-checkout' );
		}

		if ( is_product() ) {
			if ( 'grid' === \Minimog_Woo::instance()->get_single_product_images_style() ) {
				wp_enqueue_script( 'minimog-grid-layout' );
			}

			wp_enqueue_style( 'lightgallery' );
			wp_enqueue_script( 'lightgallery' );
			wp_enqueue_script( 'minimog-quantity-button' );
			wp_enqueue_script( 'minimog-accordion' );
			wp_enqueue_script( 'minimog-tab-panel' );
			wp_enqueue_script( 'minimog-modal' );
			wp_enqueue_script( 'spritespin' ); // Product 360
			wp_enqueue_script( 'readmore' ); // For collapsed content & comments.

			/**
			 * Used for quantity select.
			 */
			wp_enqueue_script( 'minimog-nice-select' );

			wp_enqueue_script( 'minimog-woo-single' );
			wp_enqueue_script( 'minimog-woo-questions' );

			if ( '1' === \Minimog_Woo::instance()->get_product_setting( 'single_product_sticky_enable' ) ) {
				wp_enqueue_script( 'hc-sticky' );
			}

			$single_product_variables = array(
				'featureStyle'              => \Minimog_Woo::instance()->get_single_product_images_style(),
				'i18n_required_rating_text' => esc_attr__( 'Please select a rating', 'minimog' ),
				'review_rating_required'    => wc_review_ratings_required() ? 'yes' : 'no',
				'singleProductStickyBar'    => \Minimog::setting( 'single_product_sticky_bar_enable' ),
				'i18n'                      => [
					'filesSelected' => sprintf( esc_html__( '%s files selected', 'minimog' ), '{count}' ),
					'readMore'      => esc_html__( 'Read more', 'minimog' ),
					'readLess'      => esc_html__( 'Read less', 'minimog' ),
				],
			);
			wp_localize_script( 'minimog-woo-single', '$minimogProductSingle', $single_product_variables );
		}
	}
}

Enqueue::instance()->initialize();
