<?php

namespace Minimog\Woo;

defined( 'ABSPATH' ) || exit;

class Wishlist {
	protected static $instance = null;

	protected static $added_products    = array();
	protected static $added_product_ids = array();
	protected static $localization      = array();

	public static function instance() {
		if ( null === self::$instance ) {
			self::$instance = new self();
		}

		return self::$instance;
	}

	public function initialize() {
		if ( ! $this->is_activate() ) {
			return;
		}

		add_action( 'init', [ $this, 'init' ] );

		add_filter( 'woosw_button_position_archive', '__return_zero_string' );
		add_filter( 'woosw_button_position_single', '__return_zero_string' );

		add_action( 'wp_enqueue_scripts', [ $this, 'frontend_scripts' ] );
	}

	public function is_activate() {
		if ( class_exists( 'WPCleverWoosw' ) ) {
			return true;
		}

		return false;
	}

	public function init() {
		// Localization.
		self::$localization = (array) get_option( 'woosw_localization' );

		// Added products.
		$key = isset( $_COOKIE['woosw_key'] ) ? $_COOKIE['woosw_key'] : '#';

		if ( get_option( 'woosw_list_' . $key ) ) {
			self::$added_products = get_option( 'woosw_list_' . $key );

			self::$added_product_ids = array_keys( self::$added_products );
		}
	}

	public function frontend_scripts() {
		$min = \Minimog_Enqueue::instance()->get_min_suffix();
		// Remove styles from plugin.
		wp_dequeue_style( 'woosw-feather' );
		wp_dequeue_style( 'woosw-frontend' );

		wp_register_script( 'minimog-woo-wishlist', MINIMOG_THEME_URI . "/assets/js/woo/wishlist{$min}.js", [
			'jquery',
			'woosw-frontend',
		], MINIMOG_THEME_VERSION, true );

		wp_enqueue_script( 'minimog-woo-wishlist' );
		$js_variables = array(
			'button'      => self::instance()->get_localization( 'button', __( 'Add to wishlist', 'minimog' ) ),
			'buttonAdded' => self::instance()->get_localization( 'button_added', __( 'Browse wishlist', 'minimog' ) ),
		);
		wp_localize_script( 'minimog-woo-wishlist', '$minimogWishlist', $js_variables );
	}

	public function get_localization( $key = '', $default = '' ) {
		$str = '';

		if ( ! empty( $key ) && ! empty( self::$localization[ $key ] ) ) {
			$str = self::$localization[ $key ];
		} elseif ( ! empty( $default ) ) {
			$str = $default;
		}

		return apply_filters( 'woosw_localization_' . $key, $str );
	}

	public static function output_button( $args = array() ) {
		if ( '1' !== \Minimog::setting( 'shop_archive_wishlist' ) || ! self::instance()->is_activate() ) {
			return;
		}

		global $product;

		$product_id = $product->get_id();

		$defaults = array(
			'show_tooltip'     => false,
			'tooltip_position' => 'top',
			'tooltip_skin'     => '',
			'style'            => '02',
		);
		$args     = wp_parse_args( $args, $defaults );

		$_wrapper_classes = "product-action wishlist-btn style-{$args['style']}";

		if ( $args['show_tooltip'] === true ) {
			$_wrapper_classes .= ' hint--bounce';
			$_wrapper_classes .= " hint--{$args['tooltip_position']}";

			if ( ! empty( $args['tooltip_skin'] ) ) {
				$_wrapper_classes .= " hint--{$args['tooltip_skin']}";
			}
		}

		if ( in_array( $product_id, self::$added_product_ids, true ) ) {
			$text = self::instance()->get_localization( 'button_added', __( 'Browse wishlist', 'minimog' ) );
		} else {
			$text = self::instance()->get_localization( 'button', __( 'Add to wishlist', 'minimog' ) );
		}
		?>
		<div class="<?php echo esc_attr( $_wrapper_classes ); ?>"
		     data-hint="<?php echo esc_attr( $text ); ?>">
			<?php echo do_shortcode( '[woosw id="' . $product_id . '" type="link"]' ); ?>
		</div>
		<?php
	}

	public function can_edit( $key ) {
		if ( is_user_logged_in() ) {
			if ( get_user_meta( get_current_user_id(), 'woosw_key', true ) === $key ) {
				return true;
			}
		} else {
			if ( isset( $_COOKIE['woosw_key'] ) && ( $_COOKIE['woosw_key'] === $key ) ) {
				return true;
			}
		}

		return false;
	}
}

Wishlist::instance()->initialize();
