<?php
/**
 * Single Product Shipping
 *
 * @package Minimog/WooCommerce/Templates
 * @since   1.0.0
 * @version 1.0.0
 */

defined( 'ABSPATH' ) || exit;

global $product;

$shipping_class_id   = $product->get_shipping_class_id();
$shipping_class_name = '';
if ( $shipping_class_id ) {
	$term = get_term_by( 'id', $shipping_class_id, 'product_shipping_class' );

	if ( $term && ! is_wp_error( $term ) ) {
		$shipping_class_name = $term->name;
	}
}

$delivery_days = intval( get_option( 'woocommerce_shipping_delivery_time' ) );

$amount_for_free_shipping = Minimog\Woo\Free_Shipping_Label::instance()->get_min_free_shipping_amount();
$min_amount               = (float) $amount_for_free_shipping['amount'];
?>
<div class="entry-product-meta-shipping">
	<?php if ( ! empty( $shipping_class_name ) ) : ?>
		<div class="item product-meta-shipping-class">
			<div
				class="icon"><?php echo Minimog_Helper::get_file_contents( MINIMOG_THEME_SVG_DIR . '/font-awesome/light/truck-moving.svg' ); ?></div>
			<div class="value"><?php echo esc_html( $shipping_class_name ); ?></div>
		</div>
	<?php endif; ?>
	<?php if ( ! empty( $delivery_days ) && $delivery_days > 0 ): ?>
		<?php
		$delivery_start        = strtotime( 'now' );
		$delivery_end          = strtotime( '+' . $delivery_days . ' day' );
		$delivery_start_format = $date_end_format = 'M d,Y';

		if ( date( 'Y', $delivery_start ) === date( 'Y', $delivery_end ) ) {
			$delivery_start_format = 'M d';
		}

		$delivery_ranges = date( $delivery_start_format, $delivery_start ) . ' - ' . date( $date_end_format, $delivery_end );
		?>
		<?php ?>
		<div class="item product-meta-shipping-delivery-time">
			<div
				class="icon"><?php echo Minimog_Helper::get_file_contents( MINIMOG_THEME_SVG_DIR . '/font-awesome/light/shipping-fast.svg' ); ?></div>
			<div class="label"><?php esc_html_e( 'Estimated Delivery:', 'minimog' ); ?></div>
			<div class="value"><?php echo esc_html( $delivery_ranges ); ?></div>
		</div>
	<?php endif; ?>

	<?php if ( $min_amount > 0 ) : ?>
		<div class="item product-meta-shipping-return">
			<div
				class="icon"><?php echo Minimog_Helper::get_file_contents( MINIMOG_THEME_SVG_DIR . '/font-awesome/light/box.svg' ); ?></div>
			<div class="label"><?php esc_html_e( 'Free Shipping & Returns:', 'minimog' ); ?></div>
			<div
				class="value"><?php echo sprintf( esc_html__( 'On all orders over %s', 'minimog' ), wc_price( $min_amount ) ); ?></div>
		</div>
	<?php endif; ?>
</div>
